@@ -50,6 +50,7 @@ QCustomFolderTree::QCustomFolderTree(QWidget *parent):QTreeWidget(parent) {
     ApplicationConfig   =NULL;
     DriveList           =NULL;
     IsRemoveAllowed     =false;
+    IsRenameAllowed     =false;
 
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this,SIGNAL(itemExpanded(QTreeWidgetItem *)),this,SLOT(s_itemExpanded(QTreeWidgetItem *)));
@@ -63,17 +64,32 @@ void QCustomFolderTree::InitDrives(cDriveList *TheDriveList) {
 
     DriveList=TheDriveList;
     foreach(cDriveDesc HDD,DriveList->List)
-        if ((!HDD.Path.startsWith("/mnt/"))||(ApplicationConfig->ShowMntDrive))
+#ifdef Q_WS_X11
+        if (HDD.Path.startsWith("/media/")
+            ||(HDD.Path=="/")
+            ||(HDD.Label==PersonalFolder)
+            ||(HDD.Path.startsWith("/mnt/")&&ApplicationConfig->ShowMntDrive)
+        )
+#endif
             addTopLevelItem(CreateItem(HDD.Label,HDD.Path,QIcon(QPixmap().fromImage(HDD.IconDrive))));
 }
 
 //====================================================================================================================
 
+void QCustomFolderTree::keyReleaseEvent(QKeyEvent *event) {
+    if (event->matches(QKeySequence::Delete)) {  if (IsRemoveAllowed) emit ActionRemoveFolder(); }
+        else if (event->key()==Qt::Key_F5)      emit ActionRefreshAll();
+        else QTreeWidget::keyReleaseEvent(event);
+}
+
+//====================================================================================================================
+
 QAction *QCustomFolderTree::CreateMenuAction(QString RessourceNameIcon,QString Text,int Data,bool Checkable,bool IsCheck) {
     QAction *Action;
     if (RessourceNameIcon!="") Action=new QAction(QIcon(RessourceNameIcon),Text,this); else Action=new QAction(Text,this);
     Action->setIconVisibleInMenu(true);
     Action->setCheckable(Checkable);
+    Action->setFont(QFont("Sans Serif",9));
     if (Checkable) Action->setChecked(IsCheck);
     Action->setData(QVariant(Data));
     return Action;
@@ -87,6 +103,7 @@ void QCustomFolderTree::s_ContextMenu(const QPoint) {
     ContextMenu->addAction(CreateMenuAction(":/img/Refresh.png",QApplication::translate("QCustomFolderTree","Refresh from here"),2,false,false));
     ContextMenu->addAction(CreateMenuAction(":/img/AddFolder.png",QApplication::translate("QCustomFolderTree","Create new subfolder"),3,false,false));
     if (IsRemoveAllowed) ContextMenu->addAction(CreateMenuAction(":/img/trash.png",QApplication::translate("QCustomFolderTree","Remove folder"),4,false,false));
+    if (IsRenameAllowed) ContextMenu->addAction(CreateMenuAction(":/img/action_edit.png",QApplication::translate("QCustomFolderTree","Rename folder"),5,false,false));
     QAction *Action=ContextMenu->exec(QCursor::pos());
     if (Action) {
         int     ActionType=Action->data().toInt();
@@ -95,13 +112,10 @@ void QCustomFolderTree::s_ContextMenu(const QPoint) {
         QString FolderPath="";
         bool    Ok;
         switch (ActionType) {
-            case 1 :
-                RefreshDriveList();
-                RefreshItemByPath(GetFolderPath(currentItem(),true),false);
-                break; // Refresh all
-            case 2 :
-                RefreshItemByPath(GetFolderPath(currentItem(),true),false);
-                break; // Refresh from here
+            case 1 :    emit ActionRefreshAll();    break;  // Refresh all
+            case 2 :    emit ActionRefreshHere();   break;  // Refresh from here
+            case 4 :    emit ActionRemoveFolder();  break;  // Remove folder
+            case 5 :    emit ActionRenameFolder();  break;  // Rename folder
             case 3 :
                 FolderPath=GetFolderPath(currentItem(),false);
                 SubFolderName=CustomInputDialog(this,QApplication::translate("QCustomFolderTree","Create folder"),QApplication::translate("QCustomFolderTree","Folder:"),QLineEdit::Normal,"",&Ok);
@@ -110,6 +124,10 @@ void QCustomFolderTree::s_ContextMenu(const QPoint) {
                     #ifdef Q_OS_LINUX
                     if (FolderName.startsWith("~")) FolderName=QDir::homePath()+FolderName.mid(1);
                     #endif
+                    #ifdef Q_OS_WIN
+                        if (FolderName.startsWith(PersonalFolder)) FolderName=QDir::homePath()+FolderName.mid(PersonalFolder.length());
+                        FolderName=AdjustDirForOS(FolderName);
+                    #endif
                     if (QDir().mkdir(FolderName)) RefreshItemByPath(GetFolderPath(currentItem(),true),false); else {
                         QString ErrorMsg=QString(QApplication::translate("QCustomFolderTree","Error %1:")).arg(errno)+QString().fromLocal8Bit(strerror(errno));
                         CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("QCustomFolderTree","Create folder"),
@@ -120,9 +138,6 @@ void QCustomFolderTree::s_ContextMenu(const QPoint) {
                     SetSelectItemByPath(FolderName);
                 }
                 break; // Create new subfolder
-            case 4 :
-                emit ActionRemoveFolder();
-                break; // Remove
         }
 
         // delete menu
@@ -138,7 +153,15 @@ void QCustomFolderTree::s_ContextMenu(const QPoint) {
 bool QCustomFolderTree::IsFolderHaveChild(QString FilePath) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:QTreeWidgetItem::IsFolderHaveChild");
 
+    #ifdef Q_OS_LINUX
+    if (FilePath.startsWith("~")) FilePath=QDir::homePath()+FilePath.mid(1);
+    #endif
+    #ifdef Q_OS_WIN
+        if (FilePath.startsWith(PersonalFolder)) FilePath=QDir::homePath()+FilePath.mid(PersonalFolder.length());
+        FilePath=AdjustDirForOS(FilePath);
+    #endif
     QFileInfoList List=QDir(FilePath).entryInfoList(QDir::Dirs|QDir::NoDotAndDotDot|(ApplicationConfig->ShowHiddenFilesAndDir?QDir::Hidden:QDir::Dirs));
+    int i=0; while (i<List.count()) if ((ApplicationConfig->ShowHiddenFilesAndDir)||(!List[i].fileName().startsWith("."))) i++; else List.removeAt(i);
     return List.count()>0;
 }
 
@@ -199,11 +222,9 @@ QString QCustomFolderTree::GetFolderPath(const QTreeWidgetItem *Item,bool TreeMo
             if (!TreeMode) {
                 // Search if text is a registered alias, then replace text with path
                 for (int i=0;i<DriveList->List.count();i++) if (DriveList->List[i].Label==RootStr) {
-                    if (RootStr!=QApplication::translate("QCustomFolderTree","Personal folder")) RootStr=DriveList->List[i].Path; else
+                    if (RootStr!=PersonalFolder) RootStr=DriveList->List[i].Path;
                         #ifdef Q_OS_LINUX
-                            RootStr="~";
-                        #else
-                            RootStr="%HOMEDRIVE%%HOMEPATH%";
+                            else RootStr="~";
                         #endif
                 }
             }
@@ -234,7 +255,6 @@ QString QCustomFolderTree::GetCurrentFolderPath() {
 
 void QCustomFolderTree::s_itemExpanded(QTreeWidgetItem *item) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:QCustomFolderTree::expandItem");
-
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
     // Expand node if necessary
@@ -247,15 +267,35 @@ void QCustomFolderTree::s_itemExpanded(QTreeWidgetItem *item) {
         QFileInfoList       Directorys;
         int                 i,k;
 
+        #ifdef Q_OS_LINUX
+            if (Folder.startsWith("~")) Folder=QDir::homePath()+Folder.mid(1);
+        #endif
+        #ifdef Q_OS_WIN
+            if (Folder.startsWith(PersonalFolder)) Folder=QDir::homePath()+Folder.mid(PersonalFolder.length());
+            Folder=AdjustDirForOS(Folder);
+        #endif
+
         // remove tag to sub item
         QTreeWidgetItem *SubItem=CurItem->child(0);
         CurItem->removeChild(SubItem);
         delete SubItem;
 
+        #ifdef Q_OS_WIN
+            bool IsPersonalFolder=Folder.startsWith(PersonalFolder);
+            if (IsPersonalFolder) Folder=QDir::homePath()+Folder.mid(PersonalFolder.length());
+            Folder=AdjustDirForOS(Folder);
+        #endif
         Directorys=QDir(Folder).entryInfoList(QDir::Dirs|QDir::NoDotAndDotDot|(ApplicationConfig->ShowHiddenFilesAndDir?QDir::Hidden:QDir::Dirs));
+        i=0; while (i<Directorys.count()) if ((ApplicationConfig->ShowHiddenFilesAndDir)||(!Directorys[i].fileName().startsWith("."))) i++; else Directorys.removeAt(i);
         for (k=0;k<Directorys.count();k++)
-            if (Directorys[k].isDir())
+            if (Directorys[k].isDir()) {
+                #ifdef Q_OS_WIN
+                if (IsPersonalFolder)
+                    CurItem->addChild(CreateItem(Directorys[k].fileName(),PersonalFolder+QDir::separator()+Directorys[k].fileName(),DriveList->GetFolderIcon(Directorys[k].absoluteFilePath())));
+                else
+                #endif
                 CurItem->addChild(CreateItem(Directorys[k].fileName(),Directorys[k].absoluteFilePath(),DriveList->GetFolderIcon(Directorys[k].absoluteFilePath())));
+            }
 
         // Unselect previous selected item and then select new one
         QList<QTreeWidgetItem *>    List  =selectedItems();
@@ -282,8 +322,7 @@ cDriveDesc *QCustomFolderTree::SearchRealDrive(QString Path) {
         if (Path.startsWith("~")) Path=QDir::homePath()+Path.mid(1);
     #endif
     #ifdef Q_OS_WIN
-        Path.replace("%HOMEDRIVE%%HOMEPATH%",DriveList->List[0].Path,Qt::CaseInsensitive);
-        Path.replace("%USERPROFILE%",DriveList->List[0].Path,Qt::CaseInsensitive);
+        if (Path.startsWith(PersonalFolder)) Path=QDir::homePath()+Path.mid(PersonalFolder.length());
         Path=AdjustDirForOS(Path);
     #endif
 
@@ -332,11 +371,18 @@ void QCustomFolderTree::SetSelectItemByPath(QString Path) {
     QTreeWidgetItem     *Current=NULL;
 
     #ifdef Q_OS_LINUX
-        if (Path.startsWith("~")) Path=QApplication::translate("QCustomFolderTree","Personal folder")+Path.mid(1);
+        if (Path.startsWith("~")) Path=PersonalFolder+Path.mid(1);
     #endif
     #ifdef Q_OS_WIN
-        Path.replace("%HOMEDRIVE%%HOMEPATH%",QApplication::translate("QCustomFolderTree","Personal folder"),Qt::CaseInsensitive);
-        Path.replace("%USERPROFILE%",QApplication::translate("QCustomFolderTree","Personal folder"),Qt::CaseInsensitive);
+        Path=AdjustDirForOS(Path);
+        // Remove labels
+        int StartLabel=Path.indexOf("[");
+        int EndLabel  =(StartLabel>0?Path.indexOf("]\\"):0);
+        if (EndLabel>0) EndLabel+=2;
+        if ((StartLabel>0)&&(EndLabel>StartLabel)) {
+            QString OldPath=Path;
+            Path=OldPath.left(StartLabel)+OldPath.right(OldPath.length()-EndLabel);
+        }
     #endif
 
     // Create a list with each part of the wanted Path
@@ -354,7 +400,7 @@ void QCustomFolderTree::SetSelectItemByPath(QString Path) {
     i=0;
     Current=topLevelItem(0);
 
-    while ((Current!=NULL)&&(i<Folders.count())) {
+    while ((Current!=NULL)&&(i<Folders.count())&&(Folders[i]!="")) {
         if (i==0) {
             // Search in topitemlist : Note : Search in reverse order to give preference to drive instead of /mnt/drive or /media/drive
             j=topLevelItemCount()-1;
@@ -364,8 +410,8 @@ void QCustomFolderTree::SetSelectItemByPath(QString Path) {
         } else {
             j=0;
             // Search in current item child list
-            while ((j<Current->childCount())&&(Current->child(j)->text(0)!=Folders[i])) j++;
-            if ((j<Current->childCount())&&(Current->child(j)->text(0)==Folders[i])) Current=Current->child(j);
+            while ((j<Current->childCount())&&(Current->child(j)->text(0).compare(Folders[i])!=0)&&(Current->child(j)->text(0)!=Folders[i]+QDir::separator())) j++;
+            if ((j<Current->childCount())&&((Current->child(j)->text(0)==Folders[i])||(Current->child(j)->text(0).compare(Folders[i]+QDir::separator())==0))) Current=Current->child(j);
                 else Current=NULL;
         }
         if (Current) {
@@ -380,7 +426,12 @@ void QCustomFolderTree::SetSelectItemByPath(QString Path) {
                 #ifdef Q_OS_LINUX
                 if (RealPath.startsWith("~")) RealPath=QDir::homePath()+RealPath.mid(1);
                 #endif
+                #ifdef Q_OS_WIN
+                if (RealPath.startsWith(PersonalFolder)) RealPath=QDir::homePath()+RealPath.mid(PersonalFolder.length());
+                RealPath=AdjustDirForOS(RealPath);
+                #endif
                 Directorys=QDir(RealPath).entryInfoList(QDir::Dirs|QDir::NoDotAndDotDot|(ApplicationConfig->ShowHiddenFilesAndDir?QDir::Hidden:QDir::Dirs));
+                int z=0; while (z<Directorys.count()) if ((ApplicationConfig->ShowHiddenFilesAndDir)||(!Directorys[z].fileName().startsWith("."))) z++; else Directorys.removeAt(z);
                 for (k=0;k<Directorys.count();k++) Current->addChild(CreateItem(Directorys[k].fileName(),Directorys[k].absoluteFilePath(),DriveList->GetFolderIcon(Directorys[k].absoluteFilePath())));
             }
             Current->setExpanded(true);
@@ -416,6 +467,7 @@ public:
 
 void QCustomFolderTree::RefreshItemByPath(QString Path,bool RefreshAll,int Level) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:QCustomFolderTree::SetSelectedItemByPath");
+    Path=AdjustDirForOS(Path);
 
     QString RealPath=Path;
     int     i,j;
@@ -442,7 +494,7 @@ void QCustomFolderTree::RefreshItemByPath(QString Path,bool RefreshAll,int Level
 
     // Adjust Path
     #ifdef Q_OS_LINUX
-    Path.replace("~",QApplication::translate("QCustomFolderTree","Personal folder"));
+    Path.replace("~",PersonalFolder);
     #endif
 
     // Create a list with each part of the wanted Path
@@ -454,21 +506,25 @@ void QCustomFolderTree::RefreshItemByPath(QString Path,bool RefreshAll,int Level
 
     // Now we can search corresponding item in the tree
     i=0;
-    while ((i<this->topLevelItemCount())&&(topLevelItem(i)->text(0)!=Folders[0])) i++;
-    if ((i<this->topLevelItemCount())&&(topLevelItem(i)->text(0)==Folders[0])) {
+    while ((Folders.count()>0)&&(i<this->topLevelItemCount())&&(topLevelItem(i)->text(0)!=Folders[0])&&(topLevelItem(i)->text(0)!=Folders[0]+QDir::separator())) i++;
+    if ((Folders.count()>0)&&(i<this->topLevelItemCount())&&((topLevelItem(i)->text(0)==Folders[0])||(topLevelItem(i)->text(0)==Folders[0]+QDir::separator()))) {
         // We have found the toplevel, now down the tree
         Current=topLevelItem(i);
         j=1;
         while ((Current)&&(j<Folders.count())) {
             i=0;
-            while ((i<Current->childCount())&&(Current->child(i)->text(0)!=Folders[j])) i++;
-            if ((i<Current->childCount())&&(Current->child(i)->text(0)==Folders[j])) {
+            while ((i<Current->childCount())&&(Current->child(i)->text(0)!=Folders[j])&&(Current->child(i)->text(0)!=Folders[j]+QDir::separator())) i++;
+            if ((i<Current->childCount())&&((Current->child(i)->text(0)==Folders[j])||(Current->child(i)->text(0)==Folders[j]+QDir::separator()))) {
                 Current=Current->child(i);
                 j++;
             } else Current=NULL;
         }
     }
 
+    // Don't check directory if unexpanded TAG is set !
+    if ((Current)&&(Current->childCount()==1)&&(Current->child(0)->text(0)==TAG))
+        Current=NULL;
+
     // if item found
     if (Current) {
         if (Level==0) setUpdatesEnabled(false);
@@ -500,8 +556,11 @@ void QCustomFolderTree::RefreshItemByPath(QString Path,bool RefreshAll,int Level
 
         // Construct a second list for real folders
         QFileInfoList   Directorys=QDir(RealPath).entryInfoList(QDir::Dirs|QDir::NoDotAndDotDot|(ApplicationConfig->ShowHiddenFilesAndDir?QDir::Hidden:QDir::Dirs));
+        int z=0; while (z<Directorys.count()) if ((ApplicationConfig->ShowHiddenFilesAndDir)||(!Directorys[z].fileName().startsWith("."))) z++; else Directorys.removeAt(z);
+
         QStringList     FolderToAdd;
         bool            isFound;
+
         for (i=0;i<Directorys.count();i++) {
             isFound=false;
             // for each item search if it is present in current list
@@ -521,7 +580,7 @@ void QCustomFolderTree::RefreshItemByPath(QString Path,bool RefreshAll,int Level
                 QString ChildPath=Path;
                 if (!ChildPath.endsWith(QDir::separator())) ChildPath=ChildPath+QDir::separator();
                 ChildPath=ChildPath+CurrentList[i].Item->text(0);
-                if (RefreshAll) RefreshItemByPath(ChildPath,Level+1);
+                if (RefreshAll) RefreshItemByPath(ChildPath,RefreshAll,Level+1);
             } else {
                 // remove existing folder which no longer exist
                 SubItem=CurrentList[i].Item;
@@ -580,21 +639,30 @@ void QCustomFolderTree::RefreshDriveList() {
             DriveList->List.removeAt(i);                    // Delete from drive list
         } else if (DriveList->List[i].Flag==1) {
             // Drive previously exist
-            int j=0;
-            while ((j<topLevelItemCount())&&(topLevelItem(j)->text(0)!=DriveList->List[i].Label)) j++;
-            if ((j<topLevelItemCount())&&(topLevelItem(j)->text(0)==DriveList->List[i].Label)) {
-                // if drive is not a /mnt/ drive or if we continu to display them, then update it
-                if ((!DriveList->List[i].Path.startsWith("/mnt/"))||(ApplicationConfig->ShowMntDrive)) RefreshItemByPath(DriveList->List[i].Label,true);
-                else { // if ShowMntDrive have changed, we have to delete it now
-                    QTreeWidgetItem *Item=takeTopLevelItem(j);
-                    DeleteChildItem(Item);                      // Delete item in tree
-                    delete Item;
+            #ifdef Q_WS_X11
+            if (DriveList->List[i].Path.startsWith("/media/")
+                ||(DriveList->List[i].Path=="/")
+                ||(DriveList->List[i].Label==PersonalFolder)
+                ||(DriveList->List[i].Path.startsWith("/mnt/"))
+            ) {
+            #endif
+                int j=0;
+                while ((j<topLevelItemCount())&&(topLevelItem(j)->text(0)!=DriveList->List[i].Label)) j++;
+                if ((j<topLevelItemCount())&&(topLevelItem(j)->text(0)==DriveList->List[i].Label)) {
+                    // if drive is not a /mnt/ drive and if we not continu to display them, then delete it
+                    if ((DriveList->List[i].Path.startsWith("/mnt/"))&&(!ApplicationConfig->ShowMntDrive)) {
+                        QTreeWidgetItem *Item=takeTopLevelItem(j);
+                        DeleteChildItem(Item);                      // Delete item in tree
+                        delete Item;
+                    }
+                } else {
+                    // ShowMntDrive have changed, we have to create it
+                    if ((!DriveList->List[i].Path.startsWith("/mnt/"))||(ApplicationConfig->ShowMntDrive))
+                        addTopLevelItem(CreateItem(DriveList->List[i].Label,DriveList->List[i].Path,QIcon(QPixmap().fromImage(DriveList->List[i].IconDrive))));
                 }
-            } else {
-                // ShowMntDrive have changed, we have to create it
-                if ((!DriveList->List[i].Path.startsWith("/mnt/"))||(ApplicationConfig->ShowMntDrive))
-                    addTopLevelItem(CreateItem(DriveList->List[i].Label,DriveList->List[i].Path,QIcon(QPixmap().fromImage(DriveList->List[i].IconDrive))));
+            #ifdef Q_WS_X11
             }
+            #endif
             i++;
         } else {
             // It's a new drive
