@@ -28,6 +28,7 @@
 #include <QFileInfo>
 #include <QTextStream>
 #include <QTranslator>
+#include <QTextDocument>
 
 //*****************************************************************************************************************************************
 
@@ -131,7 +132,7 @@ bool CheckFolder(QString FileToTest,QString PathToTest) {
 //      or in $$PREFIX/share/ApplicationName
 //**************************************************
 
-bool SetWorkingPath(char *argv[],QString ApplicationGroupName,QString ApplicationName,QString ConfigFileExt) {
+bool SetWorkingPath(char * const argv[],QString ApplicationGroupName,QString ApplicationName,QString ConfigFileExt) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:SetWorkingPath");
     QString StartupDir=QFileInfo(argv[0]).absolutePath();
     ToLog(LOGMSG_INFORMATION,"StartupDir "+StartupDir);
@@ -204,10 +205,6 @@ QString AdjustDirForOS(QString Dir) {
 // cBaseApplicationConfig
 //**********************************************************************************************************************
 
-//**********************************************************************************************************************
-// cBaseApplicationConfig
-//**********************************************************************************************************************
-
 cBaseApplicationConfig::cBaseApplicationConfig(QMainWindow *TheTopLevelWindow,QString TheAllowedWEBLanguage,QString TheApplicationGroupName,QString TheApplicationName,QString TheApplicationVersion,QString TheConfigFileExt,QString TheConfigFileRootName) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cBaseApplicationConfig::cBaseApplicationConfig");
 
@@ -218,6 +215,8 @@ cBaseApplicationConfig::cBaseApplicationConfig(QMainWindow *TheTopLevelWindow,QS
     ApplicationVersion      =TheApplicationVersion;        // Application version
     ConfigFileExt           =TheConfigFileExt;             // File extension of configuration files
     ConfigFileRootName      =TheConfigFileRootName;        // Name of root node in the config xml file
+
+    if (ApplicationVersion.startsWith(ApplicationName)) ApplicationVersion.mid(ApplicationVersion.indexOf(ApplicationName)+ApplicationName.length()+1);
     if (ApplicationGroupName!=ApplicationName) ToLog(LOGMSG_INFORMATION,QString("Starting %1 %2 %3").arg(ApplicationGroupName).arg(ApplicationName).arg(ApplicationVersion));
         else ToLog(LOGMSG_INFORMATION,QString("Starting %1 %2").arg(ApplicationGroupName).arg(ApplicationVersion));
 }
@@ -245,20 +244,27 @@ void cBaseApplicationConfig::PreloadSystemIcons() {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cBaseApplicationConfig::PreloadSystemIcons");
 
     ToLog(LOGMSG_INFORMATION,"Loading system icons...");
-
-    DefaultCDROMIcon.LoadIconsFromIMG(  "cdrom.png");
-    DefaultHDDIcon.LoadIconsFromIMG(    "hdd.png");
-    DefaultUSBIcon.LoadIconsFromIMG(    "usb.png");
-    DefaultREMOTEIcon.LoadIconsFromIMG( "hdd-lan.png");
-    DefaultFOLDERIcon.LoadIconsFromIMG( "directory.png");
-    DefaultDelayedIcon.LoadIconsFromIMG("delayed.png");
-    DefaultFFDIcon.LoadIconsFromIMG(    "ffDiaporama.png");
-    DefaultThumbIcon.LoadIconsFromIMG(  "Thumbnails.png");
-    DefaultIMAGEIcon.LoadIconsFromIMG(  "image.png");
-    DefaultVIDEOIcon.LoadIconsFromIMG(  "video.png");
-    DefaultMUSICIcon.LoadIconsFromIMG(  "audio.png");
-    DefaultUSERIcon.LoadIconsFromIMG(   "folder_home.png");
-    DefaultFILEIcon.LoadIconsFromIMG(   "file.png");
+    #ifdef Q_OS_WIN
+    if (QSysInfo().WindowsVersion>=0x0090) { // At least Windows 7
+        DefaultUSERIcon.LoadIcons(GetIconForFileOrDir("%SystemRoot%\\system32\\imageres.dll",117));
+        DefaultCDROMIcon.LoadIcons(GetIconForFileOrDir("%SystemRoot%\\system32\\shell32.dll",11));
+        DefaultHDDIcon.LoadIcons(GetIconForFileOrDir("%SystemRoot%\\system32\\shell32.dll",8));
+        DefaultFOLDERIcon.LoadIcons(GetIconForFileOrDir("%SystemRoot%\\system32\\shell32.dll",3));
+    }
+    #endif
+    if (DefaultCDROMIcon.Icon16.isNull())   DefaultCDROMIcon.LoadIconsFromIMG(  "cdrom.png");
+    if (DefaultHDDIcon.Icon16.isNull())     DefaultHDDIcon.LoadIconsFromIMG(    "hdd.png");
+    if (DefaultUSBIcon.Icon16.isNull())     DefaultUSBIcon.LoadIconsFromIMG(    "usb.png");
+    if (DefaultREMOTEIcon.Icon16.isNull())  DefaultREMOTEIcon.LoadIconsFromIMG( "hdd-lan.png");
+    if (DefaultFOLDERIcon.Icon16.isNull())  DefaultFOLDERIcon.LoadIconsFromIMG( "directory.png");
+    if (DefaultDelayedIcon.Icon16.isNull()) DefaultDelayedIcon.LoadIconsFromIMG("delayed.png");
+    if (DefaultFFDIcon.Icon16.isNull())     DefaultFFDIcon.LoadIconsFromIMG(    "ffDiaporama.png");
+    if (DefaultThumbIcon.Icon16.isNull())   DefaultThumbIcon.LoadIconsFromIMG(  "Thumbnails.png");
+    if (DefaultIMAGEIcon.Icon16.isNull())   DefaultIMAGEIcon.LoadIconsFromIMG(  "image.png");
+    if (DefaultVIDEOIcon.Icon16.isNull())   DefaultVIDEOIcon.LoadIconsFromIMG(  "video.png");
+    if (DefaultMUSICIcon.Icon16.isNull())   DefaultMUSICIcon.LoadIconsFromIMG(  "audio.png");
+    if (DefaultUSERIcon.Icon16.isNull())    DefaultUSERIcon.LoadIconsFromIMG(   "folder_home.png");
+    if (DefaultFILEIcon.Icon16.isNull())    DefaultFILEIcon.LoadIconsFromIMG(   "file.png");
     VideoMask_120=QImage(":/img/VideoMask_120x180.png");
     VideoMask_150=QImage(":/img/VideoMask_150x200.png");
     VideoMask_162=QImage(":/img/VideoMask_162x216.png");
@@ -305,6 +311,7 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
 
     // Initialise all variables and set them default value
     ParentWindow            = NULL;
+    StartingPath            = AdjustDirForOS(QDir::currentPath());
     this->ForceLanguage     = ForceLanguage;
     MainWinState            = false;                                                        // WindowsSettings-ismaximized
     RestoreWindow           = true;                                                         // if true then restore windows size and position
@@ -318,10 +325,8 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
     #endif
     MemCacheMaxValue        = 512*1024*1024;                                                // 512 Mb for image cache
     Crop1088To1080          = true;                                                         // Automaticaly crop video from 1088 lines to 1080 (CANON)
-    ApplyTransfoPreview     = true;                                                         // True if image transformation are apply during preview
-    QuickResamplingPreview  = false;                                                        // If true then use quick resampling during preview
+    Deinterlace             = false;
     Smoothing               = true;                                                         // True do smoothing in preview
-    AllowCachedTransfoImages= false;                                                        // Allow cached transformed images
 
     //*********************************************************************
     // Search plateforme and define specific value depending on plateforme
@@ -383,9 +388,11 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
     AllowVideoExtension.append("ogv");     AllowVideoExtension.append("OGV");
     AllowVideoExtension.append("webm");    AllowVideoExtension.append("WEBM");
     AllowVideoExtension.append("dv");      AllowVideoExtension.append("DV");
-#ifdef LIBAV_AVCHD
+    AllowVideoExtension.append("wmv");     AllowVideoExtension.append("WMV");
+    #ifdef LIBAV_AVCHD
     AllowVideoExtension.append("mts");     AllowVideoExtension.append("MTS");
-#endif
+    AllowVideoExtension.append("m2ts");    AllowVideoExtension.append("M2TS");
+    #endif
     // List of all file extension allowed for image
     AllowImageExtension.append("bmp");     AllowImageExtension.append("BMP");
     AllowImageExtension.append("gif");     AllowImageExtension.append("GIF");
@@ -414,7 +421,7 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
     AllowMusicExtension.append("flac");    AllowMusicExtension.append("FLAC");
 
     // set value of external tools path (depending on operating system)
-    PathEXIV2       = "exiv2";                       // FileName of exiv2 (with path) : Linux version
+    PathEXIV2                   = "exiv2";                       // FileName of exiv2 (with path) : Linux version
     RememberLastDirectories     = true;                         // If true, Remember all directories for future use
     #ifdef Q_OS_WIN
         LastMediaPath           = WINDOWS_PICTURES;             // Last folder use for image/video
@@ -429,8 +436,8 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
     ShowHiddenFilesAndDir   =false;
     ShowMntDrive            =false;
     ShowFoldersFirst        =true;
-    CurrentFilter           =OBJECTTYPE_UNMANAGED;
-    CurrentMode             =DISPLAY_DATA;
+    CurrentFilter           =OBJECTTYPE_MANAGED;
+    CurrentMode             =DISPLAY_ICON100;
     DisplayFileName         =true;
     MinimumEXIFHeight       =100;
     Image_ThumbWidth        =300;
@@ -440,6 +447,62 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
     Video_ThumbWidth        =162;
     Video_ThumbHeight       =216;
 
+    // First thing to do is to load ForceLanguage from USERCONFIGFILE and install translator to fix text codec !
+    QFile           file(UserConfigFile);
+    QDomDocument    domDocument;
+    QDomElement     root;
+    QString         errorStr;
+    int             errorLine,errorColumn;
+
+    if (file.open(QFile::ReadOnly | QFile::Text)) {
+        QTextStream in(&file);
+        if (domDocument.setContent(in.readAll(),true,&errorStr,&errorLine,&errorColumn)) {
+            domDocument.setContent(domDocument.toString(4),true,&errorStr,&errorLine,&errorColumn);
+            if ((root.elementsByTagName("GlobalPreferences").length()>0)&&(root.elementsByTagName("GlobalPreferences").item(0).isElement()==true)) {
+                QDomElement Element=root.elementsByTagName("GlobalPreferences").item(0).toElement();
+                if ((Element.hasAttribute("ForceLanguage"))&&(ForceLanguage=="")) ForceLanguage=Element.attribute("ForceLanguage");
+            }
+        }
+    }
+    // Search system language
+    CurrentLanguage=QLocale::system().name().left(2);
+    if (ForceLanguage!="") CurrentLanguage=ForceLanguage;
+
+    // Validate if system locale is supported and if not force use of "en"
+    if ((CurrentLanguage!="en")&&(!QFileInfo(QString("locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm")).exists())) {
+        ToLog(LOGMSG_INFORMATION,QString("Language \"%1\" not found : switch to english").arg(CurrentLanguage));
+        CurrentLanguage="en";
+    }
+
+    // Install translation (if needed)
+    if (CurrentLanguage!="en") {
+        // Load translation
+        if (!translator.load(QString("locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm"))) {
+            ToLog(LOGMSG_WARNING,QString("Error loading application translation file ... locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm"));
+            exit(1);
+        } else ToLog(LOGMSG_INFORMATION,QString("Loading application translation file ... locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm"));
+
+        // Try to load QT system translation file in current project local folder
+        if (QFileInfo(QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm")).exists()) {
+            if (!QTtranslator.load(QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"))) {
+                ToLog(LOGMSG_WARNING,QString("Error loading QT system translation file ... locale")+QDir::separator()+QString("qt_")+CurrentLanguage+".qm");
+            } else {
+                ToLog(LOGMSG_INFORMATION,QString("Loading QT system translation file ... locale")+QDir::separator()+QString("qt_")+CurrentLanguage+".qm");
+            }
+        } else if (QFileInfo(QString("..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm")).exists()) {
+            // If not then try to load QT system translation file in parrent project local folder
+            if (!QTtranslator.load(QString("..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"))) {
+                ToLog(LOGMSG_WARNING,QString("Error loading QT system translation file ... ..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"));
+            } else {
+                ToLog(LOGMSG_INFORMATION,QString("Loading QT system translation file ... ..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"));
+            }
+        }
+        App->installTranslator(&translator);
+        App->installTranslator(&QTtranslator);
+    }
+
+    // Now translator are loaded, then we can load configuration files
+
     // Init all others values by call subclassing function
     InitValues();
 
@@ -451,7 +514,7 @@ bool cBaseApplicationConfig::InitConfigurationValues(QString ForceLanguage,QAppl
 
 //====================================================================================================================
 
-bool cBaseApplicationConfig::LoadConfigurationFile(LoadConfigFileType TypeConfigFile,QApplication *App) {
+bool cBaseApplicationConfig::LoadConfigurationFile(LoadConfigFileType TypeConfigFile,QApplication */*App*/) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cBaseApplicationConfig::LoadConfigurationValues"+(TypeConfigFile==USERCONFIGFILE?UserConfigFile:GlobalConfigFile));
 
     QFile           file(TypeConfigFile==USERCONFIGFILE?UserConfigFile:GlobalConfigFile);
@@ -467,9 +530,15 @@ bool cBaseApplicationConfig::LoadConfigurationFile(LoadConfigFileType TypeConfig
         IsOk=false;
     }
 
-    if (IsOk && (!domDocument.setContent(&file,true,&errorStr,&errorLine,&errorColumn))) {
-        ToLog(LOGMSG_CRITICAL,QApplication::translate("MainWindow","Error reading content of configuration file","Error message")+" "+(TypeConfigFile==USERCONFIGFILE?UserConfigFile:GlobalConfigFile));
-        IsOk=false;
+    if (IsOk) {
+        QTextStream in(&file);
+        in.setCodec("UTF-8");
+        if (!domDocument.setContent(in.readAll(),true,&errorStr,&errorLine,&errorColumn)) {
+            ToLog(LOGMSG_CRITICAL,QApplication::translate("MainWindow","Error reading content of configuration file","Error message")+" "+(TypeConfigFile==USERCONFIGFILE?UserConfigFile:GlobalConfigFile));
+            IsOk=false;
+        }
+
+        domDocument.setContent(domDocument.toString(4),true,&errorStr,&errorLine,&errorColumn);
     }
 
     if (IsOk) {
@@ -488,10 +557,8 @@ bool cBaseApplicationConfig::LoadConfigurationFile(LoadConfigFileType TypeConfig
             if (Element.hasAttribute("RasterMode"))                             RasterMode              =Element.attribute("RasterMode")=="1";
             #endif
             if (Element.hasAttribute("RestoreWindow"))                          RestoreWindow           =Element.attribute("RestoreWindow")=="1";
-            if ((Element.hasAttribute("ForceLanguage"))&&(ForceLanguage==""))   ForceLanguage           =Element.attribute("ForceLanguage");
             if (Element.hasAttribute("Crop1088To1080"))                         Crop1088To1080          =Element.attribute("Crop1088To1080")!="0";
-            if (Element.hasAttribute("ApplyTransfoPreview"))                    ApplyTransfoPreview     =Element.attribute("ApplyTransfoPreview")=="1";
-            if (Element.hasAttribute("QuickResamplingPreview"))                 QuickResamplingPreview  =Element.attribute("QuickResamplingPreview")=="1";
+            if (Element.hasAttribute("Deinterlace"))                            Deinterlace             =Element.attribute("Deinterlace")!="0";
             if (Element.hasAttribute("Smoothing"))                              Smoothing               =Element.attribute("Smoothing")=="1";
             if (Element.hasAttribute("CheckConfigAtStartup"))                   CheckConfigAtStartup    =Element.attribute("CheckConfigAtStartup")=="1";
         }
@@ -526,51 +593,9 @@ bool cBaseApplicationConfig::LoadConfigurationFile(LoadConfigFileType TypeConfig
         if ((domDocument.elementsByTagName("CacheMemory").length()>0)&&(domDocument.elementsByTagName("CacheMemory").item(0).isElement()==true)) {
             QDomElement Element=domDocument.elementsByTagName("CacheMemory").item(0).toElement();
             if (Element.hasAttribute("MemCacheMaxValue"))           MemCacheMaxValue=qlonglong(Element.attribute("MemCacheMaxValue").toInt())*qlonglong(1024*1024);
-            if (Element.hasAttribute("AllowCachedTransfoImages"))   AllowCachedTransfoImages=Element.attribute("AllowCachedTransfoImages")=="1";
         }
     }
 
-    if (TypeConfigFile==USERCONFIGFILE) {
-        // Search system language
-
-        CurrentLanguage=QLocale::system().name().left(2);
-        if (ForceLanguage!="") CurrentLanguage=ForceLanguage;
-
-        // Validate if system locale is supported and if not force use of "en"
-        if ((CurrentLanguage!="en")&&(!QFileInfo(QString("locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm")).exists())) {
-            ToLog(LOGMSG_INFORMATION,QString("Language \"%1\" not found : switch to english").arg(CurrentLanguage));
-            CurrentLanguage="en";
-        }
-
-        // Install translation (if needed)
-        if (CurrentLanguage!="en") {
-            // Load translation
-            if (!translator.load(QString("locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm"))) {
-                ToLog(LOGMSG_WARNING,QString("Error loading application translation file ... locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm"));
-                exit(1);
-            } else ToLog(LOGMSG_INFORMATION,QString("Loading application translation file ... locale")+QDir().separator()+ApplicationName+QString("_")+CurrentLanguage+QString(".qm"));
-
-            // Try to load QT system translation file in current project local folder
-            if (QFileInfo(QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm")).exists()) {
-                if (!QTtranslator.load(QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"))) {
-                    ToLog(LOGMSG_WARNING,QString("Error loading QT system translation file ... locale")+QDir::separator()+QString("qt_")+CurrentLanguage+".qm");
-                } else {
-                    ToLog(LOGMSG_INFORMATION,QString("Loading QT system translation file ... locale")+QDir::separator()+QString("qt_")+CurrentLanguage+".qm");
-                }
-            } else if (QFileInfo(QString("..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm")).exists()) {
-                // If not then try to load QT system translation file in parrent project local folder
-                if (!QTtranslator.load(QString("..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"))) {
-                    ToLog(LOGMSG_WARNING,QString("Error loading QT system translation file ... ..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"));
-                } else {
-                    ToLog(LOGMSG_INFORMATION,QString("Loading QT system translation file ... ..")+QDir::separator()+QString("..")+QDir::separator()+QString("locale")+QDir::separator()+QString("qt_")+CurrentLanguage+QString(".qm"));
-                }
-            }
-            App->installTranslator(&translator);
-            App->installTranslator(&QTtranslator);
-        }
-
-    }
-
     return IsOk && LoadValueFromXML(root,TypeConfigFile);
 }
 
@@ -581,7 +606,7 @@ bool cBaseApplicationConfig::SaveConfigurationFile() {
 
     // Save all option to the configuration file
     QFile           file(UserConfigFile);
-    QDomDocument    domDocument(ApplicationName);
+    QDomDocument    domDocument(ApplicationName);   domDocument.appendChild(domDocument.createProcessingInstruction("xml", "version=\"1.0\" encoding=\"UTF-8\""));
     QDomElement     root;
 
     // Ensure destination exist
@@ -602,8 +627,7 @@ bool cBaseApplicationConfig::SaveConfigurationFile() {
     Element.setAttribute("RestoreWindow",           RestoreWindow?"1":"0");
     Element.setAttribute("ForceLanguage",           ForceLanguage);
     Element.setAttribute("Crop1088To1080",          Crop1088To1080?"1":"0");
-    Element.setAttribute("ApplyTransfoPreview",     ApplyTransfoPreview?"1":0);
-    Element.setAttribute("QuickResamplingPreview",  QuickResamplingPreview?"1":0);
+    Element.setAttribute("Deinterlace",             Deinterlace?"1":"0");
     Element.setAttribute("Smoothing",               Smoothing?"1":0);
     Element.setAttribute("CheckConfigAtStartup",    CheckConfigAtStartup?"1":"0");
     root.appendChild(Element);
@@ -632,7 +656,6 @@ bool cBaseApplicationConfig::SaveConfigurationFile() {
 
     Element=domDocument.createElement("CacheMemory");
     Element.setAttribute("MemCacheMaxValue",        MemCacheMaxValue/(1024*1024));
-    Element.setAttribute("AllowCachedTransfoImages",AllowCachedTransfoImages?"1":"0");
     root.appendChild(Element);
 
     // Save windows size and position
@@ -646,6 +669,7 @@ bool cBaseApplicationConfig::SaveConfigurationFile() {
         return false;
     }
     QTextStream out(&file);
+    out.setCodec(QTextCodec::codecForName("UTF-8"));
     domDocument.save(out,4);
     file.close();
     return true;
