@@ -35,24 +35,21 @@
 
 // Include some common various class
 #include "cDeviceModelDef.h"                // Contains ffmpeg include
-#include "cFilterTransformObject.h"
 #include "cSoundBlockList.h"
 #include "cCustomIcon.h"
 
 // Other third party library inclusions
 
 //****************************************************************************************************************************************************************
-// EXIV2 PART [Linux only - Windows use binary version]
+// EXIV2 PART
 //****************************************************************************************************************************************************************
-//#ifdef Q_OS_LINUX
-    #include <exiv2/exif.hpp>
-    #if (EXIV2_MAJOR_VERSION==0) && (EXIV2_MINOR_VERSION>20)
-        #include <exiv2/exiv2.hpp>
-        #define EXIV2WITHPREVIEW
-    #else
-        #include <exiv2/image.hpp>
-    #endif
-//#endif
+#include <exiv2/exif.hpp>
+#if (EXIV2_MAJOR_VERSION==0) && (EXIV2_MINOR_VERSION>20)
+    #include <exiv2/exiv2.hpp>
+    #define EXIV2WITHPREVIEW
+#else
+    #include <exiv2/image.hpp>
+#endif
 
 //****************************************************************************************************************************************************************
 // TAGLIB PART
@@ -94,19 +91,6 @@
 
 //****************************************************************************************************************************************************************
 
-// Define possible values for images geometry
-#define IMAGE_GEOMETRY_UNKNOWN              0   // undefined image geometry
-#define IMAGE_GEOMETRY_3_2                  1   // Standard 3:2 landscape image
-#define IMAGE_GEOMETRY_2_3                  2   // Standard 3:2 portrait image
-#define IMAGE_GEOMETRY_4_3                  3   // Standard 4:3 landscape image
-#define IMAGE_GEOMETRY_3_4                  4   // Standard 4:3 portrait image
-#define IMAGE_GEOMETRY_16_9                 5   // Standard 16:9 landscape image
-#define IMAGE_GEOMETRY_9_16                 6   // Standard 16:9 portrait image
-#define IMAGE_GEOMETRY_40_17                7   // Standard cinema landscape image
-#define IMAGE_GEOMETRY_17_40                8   // Standard cinema portrait image
-
-//****************************************************************************************************************************************************************
-
 class cBaseMediaFile : public cCustomIcon {
 public:
     int                     ObjectType;
@@ -124,13 +108,14 @@ public:
     int                     ImageHeight;                    // Height of normal image
     int                     ImageOrientation;               // EXIF ImageOrientation (or -1)
     double                  AspectRatio;                    // Aspect ratio
-    cFilterTransformObject  BrushFileTransform;             // Image transformation if image from disk
+    int                     ImageType;                      // Type of image (depending on type object and size)
     cBaseApplicationConfig *ApplicationConfig;
     QStringList             InformationList;
 
     cBaseMediaFile(cBaseApplicationConfig *ApplicationConfig);
-    ~cBaseMediaFile();
+    virtual                 ~cBaseMediaFile();
 
+    virtual void            Reset();
     virtual bool            GetInformationFromFile(QString GivenFileName,QStringList *AliasList,bool *ModifyFlag);
     virtual bool            IsFilteredFile(int RequireObjectType)=0;
     virtual void            GetFullInformationFromFile()=0;
@@ -222,7 +207,7 @@ class cImageFile : public cBaseMediaFile {
 public:
     explicit cImageFile(cBaseApplicationConfig *ApplicationConfig);
 
-    virtual QImage          *ImageAt(bool PreviewMode,cFilterTransformObject *Filter);
+    virtual QImage          *ImageAt(bool PreviewMode);
     virtual QString         GetFileTypeStr();
     virtual bool            IsFilteredFile(int RequireObjectType);
     virtual void            GetFullInformationFromFile();
@@ -234,20 +219,29 @@ public:
 //*********************************************************************************************************************************************
 // Video file
 //*********************************************************************************************************************************************
+extern int MAXCACHEIMAGE;
+
+class cImageInCache {
+public:
+    qlonglong   Position;
+    QImage      Image;
+    cImageInCache(qlonglong Position,QImage *Image);
+};
 
 class cVideoFile : public cBaseMediaFile {
 public:
     bool                    IsOpen;                     // True if ffmpeg open on this file
     bool                    MusicOnly;                  // True if object is a music only file
     bool                    IsVorbis;                   // True if vorbis version must be use instead of MP3/WAV version
+    bool                    IsMTS;                      // True if file is a MTS file
     QTime                   StartPos;                   // Start position
     QTime                   EndPos;                     // End position
     QString                 Container;                  // Container type (get from file extension)
     QTime                   Duration;                   // Duration of the video
     double                  dEndFileCachePos;           // Position of the cache image of last image of the video
-    bool                    CodecUsePTS;                // true if codec use PTS (h264) if if we use only DTS
     QString                 VideoCodecInfo;
     QString                 AudioCodecInfo;
+    int                     NbrChapters;                // Number of chapters in the file
 
     // Video part
     AVFormatContext         *ffmpegVideoFile;           // LibAVFormat context
@@ -257,6 +251,7 @@ public:
     AVFrame                 *FrameBufferYUV;
     bool                    FrameBufferYUVReady;        // true if FrameBufferYUV is ready to convert
     int64_t                 FrameBufferYUVPosition;     // If FrameBufferYUV is ready to convert then keep FrameBufferYUV position
+    qlonglong               start_time;                 // At first seek 0, keep the AVFormatContext value
 
     // Audio part
     AVFormatContext         *ffmpegAudioFile;           // LibAVFormat context
@@ -265,10 +260,11 @@ public:
     int                     AudioTrackNbr;              // Number of audio stream in file
     int64_t                 LastAudioReadedPosition;    // Use to keep the last readed position to determine if a seek is needed
 
-    int                     NbrChapters;                // Number of chapters in the file
+    QList<cImageInCache>    CacheImage;
 
-    explicit    cVideoFile(int WantedObjectType,cBaseApplicationConfig *ApplicationConfig);
-    ~cVideoFile();
+    explicit                cVideoFile(int WantedObjectType,cBaseApplicationConfig *ApplicationConfig);
+                            ~cVideoFile();
+    virtual void            Reset(int TheWantedObjectType);
 
     virtual QString         GetFileTypeStr();
     virtual bool            IsFilteredFile(int RequireObjectType);
@@ -281,10 +277,45 @@ public:
     virtual bool            OpenCodecAndFile();
     virtual void            CloseCodecAndFile();
 
-    virtual QImage          *ImageAt(bool PreviewMode,qlonglong Position,qlonglong StartPosToAdd,cSoundBlockList *SoundTrackMontage,double Volume,bool ForceSoundOnly,cFilterTransformObject *Filter,bool DontUseEndPos);
-    virtual QImage          *ReadVideoFrame(qlonglong Position,bool DontUseEndPos);
+    virtual QImage          *ImageAt(bool PreviewMode,qlonglong Position,qlonglong StartPosToAdd,cSoundBlockList *SoundTrackMontage,bool Deinterlace,double Volume,bool ForceSoundOnly,bool DontUseEndPos);
+    virtual QImage          *ReadVideoFrame(bool PreviewMode,qlonglong Position,bool DontUseEndPos,bool Deinterlace);
     virtual void            ReadAudioFrame(bool PreviewMode,qlonglong Position,cSoundBlockList *SoundTrackBloc,double Volume,bool DontUseEndPos);      // MP3 and WAV
-    virtual QImage          *ConvertYUVToRGB();
+    virtual QImage          *ConvertYUVToRGB(bool PreviewMode);
+
+    //*********************
+    // video filters part
+    //*********************
+    #ifdef VIDEO_LIBAVFILTER
+        AVFilterGraph           *VideoFilterGraph;
+        AVFilterContext         *VideoFilterIn;
+        AVFilterContext         *VideoFilterOut;
+        QString                 m_filters;
+        QString                 m_filters_next;
+
+        enum EFilterFlags {
+            FILTER_NONE                 = 0x0,
+            FILTER_DEINTERLACE_YADIF    = 0x1,
+            FILTER_DEINTERLACE_ANY      = 0xf,
+            FILTER_DEINTERLACE_FLAGGED  = 0x10,
+            FILTER_DEINTERLACE_HALFED   = 0x20
+        };
+
+        virtual unsigned int    SetFilters(unsigned int flags);
+        virtual int             VideoFilter_Open(QString Filters);
+        virtual void            VideoFilter_Close();
+        virtual int             VideoFilter_Process();
+    #endif
+
+    //*********************
+    // audio filters part
+    //*********************
+    #ifdef AUDIO_LIBAVFILTER
+        AVFilterGraph           *AudioFilterGraph;
+        AVFilterContext         *AudioFilterIn;
+        AVFilterContext         *AudioFilterOut;
+        virtual int             AudioFilter_Open(QString Filters);
+        virtual void            AudioFilter_Close();
+    #endif
 };
 
 //*********************************************************************************************************************************************
