@@ -46,7 +46,11 @@ extern "C" {
 
     #include <libavcodec/version.h>
     #include <libavdevice/avdevice.h>
-    #include <libavfilter/avfilter.h>
+    #if LIBAVCODEC_VERSION_INT <= AV_VERSION_INT(53,8,0)
+        #include "libavfilter/avfilter.h"
+    #else
+        #include <libavfilter/version.h>
+    #endif
     #include <libavformat/version.h>
     #include <libavutil/avutil.h>
     #include <libswscale/swscale.h>
@@ -59,53 +63,59 @@ extern "C" {
 
     #include <libavformat/avformat.h>
     #include <libavformat/avio.h>
+
+    #if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(54,60,0)
+    #include "libavutil/samplefmt.h"
+    #include "libswresample/swresample.h"
+    #endif
+
+    // include for libavfilter
+    #if LIBAVFILTER_VERSION_INT >= AV_VERSION_INT(2,13,0)       // For all
+        #define VIDEO_LIBAVFILTER
+        #if LIBAVCODEC_VERSION_INT > AV_VERSION_INT(53,8,0)
+        #include "libavfilter/avfilter.h"
+        #endif
+        #include "libavfilter/avfiltergraph.h"
+        #if LIBAVFILTER_VERSION_INT < AV_VERSION_INT(2,23,0)    // From 2.13 to 2.23
+            #include "libavfilter/buffersrc.h"
+            #include "libavfilter/vsrc_buffer.h"
+        #elif LIBAVFILTER_VERSION_INT < AV_VERSION_INT(2,60,0)   // From 2.23 to 2.60
+            #include "libavfilter/avcodec.h"
+            #include "libavfilter/vsrc_buffer.h"
+        #elif LIBAVFILTER_VERSION_INT < AV_VERSION_INT(3,0,0)   // From 2.6 to 3.0
+            //#define AUDIO_LIBAVFILTER
+            #include "libavfilter/buffersink.h"
+            #include "libavfilter/avcodec.h"
+        #elif LIBAVFILTER_VERSION_INT < AV_VERSION_INT(3,1,0)   // From 3.0 to 3.1
+            //#define AUDIO_LIBAVFILTER
+            #include "libavfilter/buffersink.h"
+            #include "libavfilter/avcodec.h"
+        #else                                                   // From 3.1
+            //#define AUDIO_LIBAVFILTER
+            #if LIBAVFILTER_VERSION_INT >= AV_VERSION_INT(3,17,0)   // From 3.17
+                #include "libavfilter/avcodec.h"
+            #endif
+            #include "libavfilter/buffersink.h"
+            #include "libavfilter/buffersrc.h"
+        #endif
+    #endif
 }
 
-/* ********************************************************************************
-   Create define depending on libav version to control code creation
-   ********************************************************************************
-   VERSIONS:
-   ---------
-        OPERATING SYSTEM    DATE        BINARY  BIN.VERSION LIBAVUTIL   LIBAVCODEC  LIBAVFORMAT     LIBAVDEVICE     LIBAVFILTER     LIBSWSCALE
-        ----------------    ----------  ------  ----------- ----------  ----------  -----------     -----------     -----------     ----------
-        WINDOWS             LIBAV_08    avconv  0.8-1036    51.25.0     54.8.0      54.2.0          53.2.0          2.15.0          2.1.0
-
-        UBUNTU 12.04        LIBAV_08    avconv  0.8.1-4     51.22.1     53.35.0     53.21.0         53.2.0          2.15.0          2.1.0
-        UBUNTU 11.10        LIBAV_08    ffmpeg  0.7.3-4     51.7.0      53.6.0      53.3.0          53.0.0          2.4.0           2.0.0
-
-        OPENSUSE 12.1       LIBAV_08    ffmpeg  0.10.2      51.35.100   53.61.100   53.32.100       53.4.100        2.61.100        2.1.100
-        OPENSUSE 11.4       LIBAV_08    ffmpeg  0.10.2      51.35.100   53.61.100   53.32.100       53.4.100        2.61.100        2.1.100
-
-        FEDORA 16           LIBAV_07    ffmpeg  0.8.10      51.9.1      53.8.0      53.5.0          53.1.1          2.23.0          2.0.0
-
-        MAGEIA 2            LIBAV_08    ffmpeg  0.10.2      51.35.100   53.61.100   53.32.100       53.4.100        2.61.100        2.1.100
-
-*************************************************************************************************************************** */
-
-// LIBAV 0.7 = LIBAVUTIL from 51.7 to 51.21 + LIBAVCODEC from 53.6 to 53.34 + LIBAVFORMAT from 53.3 to 53.20
-#if (   ( (LIBAVUTIL_VERSION_MAJOR   ==51)&&(LIBAVUTIL_VERSION_MINOR  >=7)&&(LIBAVUTIL_VERSION_MINOR  <=21) ) && \
-        ( (LIBAVCODEC_VERSION_MAJOR  ==53)&&(LIBAVCODEC_VERSION_MINOR >=6)&&(LIBAVCODEC_VERSION_MINOR <=34) ) && \
-        ( (LIBAVFORMAT_VERSION_MAJOR ==53)&&(LIBAVFORMAT_VERSION_MINOR>=3)&&(LIBAVFORMAT_VERSION_MINOR<=20) ) )
-
-    #define LIBAV_07                            // LIBAV 0.7
-
-    #define LIBAV_FFMPEG                        // FFMPEG binary encoder support
-    #define LIBAV_TAGCHAPTERS                   // Support for TAG & CHAPTERS
-
-// LIBAV 0.8 = LIBAVUTIL from 51.22 + LIBAVCODEC from 53.35 to 54.20 + LIBAVFORMAT from 53.21 to 54.20
-#elif ( ( (LIBAVUTIL_VERSION_MAJOR==51)&&(LIBAVUTIL_VERSION_MINOR>=22) ) && \
-        ( ((LIBAVCODEC_VERSION_MAJOR==53)&&(LIBAVCODEC_VERSION_MINOR>=35))   || ((LIBAVCODEC_VERSION_MAJOR==54)&&(LIBAVCODEC_VERSION_MINOR<20)) ) && \
-        ( ((LIBAVFORMAT_VERSION_MAJOR==53)&&(LIBAVFORMAT_VERSION_MINOR>=21)) || ((LIBAVFORMAT_VERSION_MAJOR==54)&&(LIBAVFORMAT_VERSION_MINOR<20)) ) )
+// LIBAV 0.8 = LIBAVUTIL from 51.22 + LIBAVCODEC from 53.35 to 54.24 + LIBAVFORMAT from 53.21 to 54.20
+#if ( LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,22,0) && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(53,35,0) && LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(53,21,0) )
 
     #define LIBAV_08                            // LIBAV 0.8
-
     #define LIBAV_FFMPEG                        // FFMPEG binary encoder support
     #define LIBAV_AVCONV                        // AVCONV binary encoder support
     #define LIBAV_TAGCHAPTERS                   // Support for TAG & CHAPTERS
+    #define LIBAV_AVCHD                         // Support for AVCHD format (.mts)
 
-    #ifdef CODEC_FLAG2_SHOW_ALL
-//        #define LIBAV_AVCHD                         // Support for AVCHD format (.mts)
-    #endif
+// LIBAV 0.7 = LIBAVUTIL from 51.7 to 51.21 + LIBAVCODEC from 53.6 to 53.34 + LIBAVFORMAT from 53.3 to 53.20
+#elif ( LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,7,0) && LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(53,6,0) && LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(53,3,0) )
+
+    #define LIBAV_07                            // LIBAV 0.7
+    #define LIBAV_FFMPEG                        // FFMPEG binary encoder support
+    #define LIBAV_TAGCHAPTERS                   // Support for TAG & CHAPTERS
 
 #endif
 
@@ -134,7 +144,7 @@ extern "C" {
 #define STANDARD_NTSC                       1
 
 // Image size definition
-#define NBR_SIZEDEF                         9
+#define NBR_SIZEDEF                         11
 #define SIZE_QVGA                           0
 #define SIZE_HVGA                           1
 #define SIZE_VGA                            2
@@ -159,8 +169,8 @@ struct sIMAGEDEF {
     int     Extend;                                             // Padding for cinema mode with DVD
 };
 extern sIMAGEDEF DefImageFormat [2][3][NBR_SIZEDEF];            // Image format definition
-extern QString IMAGEDEFGENNAME[2][NBR_SIZEDEF];                 // Image format generic name
-extern int ORDERIMAGENAME[NBR_SIZEDEF];                         // Display order of image size
+extern QString   IMAGEDEFGENNAME[2][NBR_SIZEDEF];               // Image format generic name
+extern int       ORDERIMAGENAME[2][NBR_SIZEDEF];                // Display order of image size
 
 //============================================
 // Video codec definitions
@@ -183,25 +193,31 @@ extern int ORDERIMAGENAME[NBR_SIZEDEF];                         // Display order
 #define     VCODECST_THEORA     "THEORA"                        // String Theora
 #define     VCODEC_X264LL       8                               // x264 lossless + VPRE libx264-lossless.ffpreset ********
 #define     VCODECST_X264LL     "X264LL"                        // String x264 lossless ********
+#define     VCODEC_WMV1         9                               // Windows Media Video 7
+#define     VCODECST_WMV1       "WMV1"                          // String Windows Media Video 7
+#define     VCODEC_WMV2         10                              // Windows Media Video 8
+#define     VCODECST_WMV2       "WMV2"                          // String Windows Media Video 8
+#define     VCODEC_WMV3         11                              // Windows Media Video 9
+#define     VCODECST_WMV3       "WMV3"                          // String Windows Media Video 9
 
 struct sVideoCodecDef {
-    bool    IsFind;                                             // true if codec is supported by installed version of libav
+    bool    IsFind,IsRead;                                      // true if codec is supported for write,read by installed version of libav
     int     Codec_id;                                           // libav codec id
     int     FFD_VCODEC;                                         // ffDiaporama video codec id
     char    FFD_VCODECST[10];                                   // ffDiaporama video codec id string
     char    ShortName[50];                                      // short name of the codec (copy of the libav value)
     char    LongName[200];                                      // long name of the codec (define by this application)
     char    PossibleBitrate[200];                               // list of possible compression bit rate (define by this application)
-    char    DefaultBitrate[NBR_SIZEDEF][10];                    // prefered compression bit rate for each possible size
+    char    DefaultBitrate[2][NBR_SIZEDEF][10];                 // prefered compression bit rate for each possible size
 };
-#define NBR_VIDEOCODECDEF   9
+#define NBR_VIDEOCODECDEF   12
 extern struct sVideoCodecDef VIDEOCODECDEF[NBR_VIDEOCODECDEF];
 
 //============================================
 // Audio codec definitions
 //============================================
 struct sAudioCodecDef {
-    bool    IsFind;                                             // true if codec is supported by installed version of libav
+    bool    IsFind,IsRead;                                      // true if codec is supported for write,read by installed version of libav
     int     Codec_id;                                           // libav codec id
     char    ShortName[50];                                      // short name of the codec (copy of the libav value)
     char    LongName[200];                                      // long name of the codec (define by this application)
@@ -210,21 +226,21 @@ struct sAudioCodecDef {
     char    PossibleBitrate6CH[200];                            // list of possible compression bit rate in 5.1/6 chanels mode (define by this application)
     char    Default[10];                                        // prefered compression bit rate
 };
-#define NBR_AUDIOCODECDEF   9
+#define NBR_AUDIOCODECDEF   11
 extern struct sAudioCodecDef AUDIOCODECDEF[NBR_AUDIOCODECDEF];
 
 //============================================
 // Format container definitions
 //============================================
 struct sFormatDef {
-    bool    IsFind;                                             // true if format container is supported by installed version of libav
+    bool    IsFind,IsRead;                                      // true if format container is supported for write,read by installed version of libav
     char    ShortName[50];                                      // short name of the format container (copy of the libav value)
     char    FileExtension[10];                                  // prefered file extension for the format container (define by this application)
     char    LongName[200];                                      // long name of the codec (define by this application)
     char    PossibleVideoCodec[200];                            // list of possible video codec for this format container (using VCODECST String define)
     char    PossibleAudioCodec[200];                            // list of possible audio codec for this format container (define by this application)
 };
-#define NBR_FORMATDEF   10
+#define NBR_FORMATDEF   11
 extern struct sFormatDef FORMATDEF[NBR_FORMATDEF];
 
 #define NBR_AUDIOFORMATDEF   5
@@ -264,7 +280,7 @@ public:
     int     BckAudioBitrate;                                    // Bitrate number in sAudioCodecDef
 
     cDeviceModelDef(bool IsGlobalConf,int IndexKey);
-    ~cDeviceModelDef();
+    virtual         ~cDeviceModelDef();
 
     virtual void    SaveToXML(QDomElement &domDocument,QString ElementName);
     virtual bool    LoadFromXML(QDomElement domDocument,QString ElementName,bool IsUserConfigFile);
@@ -281,7 +297,7 @@ public:
     QStringList                 TranslatedRenderSubtype[4];                 // Translated render device subtype
 
     cDeviceModelList();
-    ~cDeviceModelList();
+    virtual         ~cDeviceModelList();
 
     virtual bool    LoadConfigurationFile(QString ConfigFileName,cBaseApplicationConfig::LoadConfigFileType TypeConfigFile);
     virtual bool    SaveConfigurationFile(QString ConfigFileName);
