@@ -325,10 +325,9 @@ void DlgBackgroundProperties::s_SelectFile() {
         delete DiaporamaObject->BackgroundBrush->Image;
         DiaporamaObject->BackgroundBrush->Image=NULL;
     } else {
-        QImage *Image=DiaporamaObject->BackgroundBrush->Image->ImageAt(true,&DiaporamaObject->BackgroundBrush->Image->BrushFileTransform);
+        QImage *Image=DiaporamaObject->BackgroundBrush->Image->ImageAt(true);
         if (Image) {
-            DiaporamaObject->BackgroundBrush->InitDefaultFramingStyle(true,double(DiaporamaObject->Parent->InternalHeight)/double(DiaporamaObject->Parent->InternalWidth));
-            DiaporamaObject->BackgroundBrush->ApplyStyle(true,DiaporamaObject->BackgroundBrush->DefaultFramingF); // Adjust to Full
+            DiaporamaObject->BackgroundBrush->ApplyAutoFraming(AUTOFRAMING_FULLMAX,1);
             delete Image;
         } else {
             delete DiaporamaObject->BackgroundBrush->Image;
@@ -423,7 +422,7 @@ void DlgBackgroundProperties::s_ImageEditCorrect() {
         AppendPartialUndo(UNDOACTION_EDITIMG,ui->ImageEditCorrectBT,false);
 
         //DlgImageCorrection Dlg(NULL,1,DiaporamaObject->BackgroundBrush,0,HELPFILE_DlgImageCorrection,((cApplicationConfig *)BaseApplicationConfig),((cApplicationConfig *)BaseApplicationConfig)->DlgImageCorrectionWSP,this);
-        DlgImageCorrection Dlg(NULL,1,DiaporamaObject->BackgroundBrush,0,DiaporamaObject->Parent->ImageGeometry,
+        DlgImageCorrection Dlg(NULL,NULL,DiaporamaObject->BackgroundBrush,0,DiaporamaObject->Parent->ImageGeometry,SPEEDWAVE_DISABLE,
                                HELPFILE_DlgImageCorrection,((cApplicationConfig *)BaseApplicationConfig),((cApplicationConfig *)BaseApplicationConfig)->DlgImageCorrectionWSP,this);
         Dlg.InitDialog();
         if (Dlg.exec()==0) {
