@@ -59,6 +59,7 @@ void DlgRenderVideo::DoInitDialog() {
 
     switch (ExportMode) {
         case EXPORTMODE_ADVANCED :  setWindowTitle(QApplication::translate("DlgRenderVideo","Advanced render video"));                          break;
+        case MODE_LOSSLESS       :  setWindowTitle(QApplication::translate("DlgRenderVideo","Render lossless video"));                          break;
         case MODE_SMARTPHONE     :  setWindowTitle(QApplication::translate("DlgRenderVideo","Render video for mobil player and smartphone"));   break;
         case MODE_MULTIMEDIASYS  :  setWindowTitle(QApplication::translate("DlgRenderVideo","Render video for multimedia system"));             break;
         case MODE_FORTHEWEB      :  setWindowTitle(QApplication::translate("DlgRenderVideo","Render video for the WEB"));                       break;
@@ -96,7 +97,10 @@ void DlgRenderVideo::DoInitDialog() {
 
     ui->IncludeSoundCB->setChecked(true);
     connect(ui->IncludeSoundCB,SIGNAL(clicked()),this,SLOT(s_IncludeSound()));
-
+    ui->HTML5UPVideoCB->setVisible(false);
+    ui->HTML5UPVideoLabel->setVisible(false);
+    ui->HTML5UPVideoCB->setChecked(false);
+    connect(ui->HTML5UPVideoCB,SIGNAL(clicked()),this,SLOT(s_HTML5UPVideo()));
     if (ExportMode==EXPORTMODE_ADVANCED) {
 
         ui->DeviceTypeLabel->setVisible(false);
@@ -104,8 +108,8 @@ void DlgRenderVideo::DoInitDialog() {
         ui->DeviceModelCB->setVisible(false);
         ui->DeviceModelLabel->setVisible(false);
         ui->RenderFormatText->setVisible(false);
-        ui->VideoFormatCB->view()->setFixedWidth(400);
-        ui->AudioFormatCB->view()->setFixedWidth(400);
+        //ui->VideoFormatCB->view()->setFixedWidth(400);
+        //ui->AudioFormatCB->view()->setFixedWidth(400);
 
         // Init format container combo
         for (int i=0;i<NBR_FORMATDEF;i++) if (FORMATDEF[i].IsFind) {
@@ -221,7 +225,7 @@ void DlgRenderVideo::DoInitDialog() {
 void DlgRenderVideo::ProjectProperties() {
     ToLog(LOGMSG_DEBUGTRACE,"IN:DlgRenderVideo::ProjectProperties");
 
-    DlgffDPjrProperties Dlg(Diaporama->ProjectInfo,HELPFILE_DlgffDPjrProperties,BaseApplicationConfig,((cApplicationConfig *)BaseApplicationConfig)->DlgffDPjrPropertiesWSP,this);
+    DlgffDPjrProperties Dlg(false,Diaporama,HELPFILE_DlgffDPjrProperties,BaseApplicationConfig,((cApplicationConfig *)BaseApplicationConfig)->DlgffDPjrPropertiesWSP,this);
     Dlg.InitDialog();
     if (Dlg.exec()==0) emit SetModifyFlag();
 }
@@ -282,7 +286,7 @@ void DlgRenderVideo::InitImageSizeCombo(int) {
     int ImageSize=ui->ImageSizeCombo->currentIndex();
     ui->ImageSizeCombo->clear();
     QStringList List;
-    for (int i=0;i<NBR_SIZEDEF;i++) List.append(QString("%1:%2#####%3").arg(DefImageFormat[Standard][Geometry][i].Name).arg(ORDERIMAGENAME[i]).arg(i));
+    for (int i=0;i<NBR_SIZEDEF;i++) if (ORDERIMAGENAME[Standard][i]!=0) List.append(QString("%1:%2#####%3").arg(DefImageFormat[Standard][Geometry][i].Name).arg(ORDERIMAGENAME[Standard][i]).arg(i));
     // Sort List
     for (int i=0;i<List.count();i++) for (int j=0;j<List.count()-1;j++) {
         QString StrA=List[j].mid(List[j].lastIndexOf(":")+1);       StrA=StrA.left(StrA.indexOf("#"));
@@ -308,12 +312,17 @@ void DlgRenderVideo::SelectDestinationFile() {
         int OutputFileFormat=ui->FileFormatCB->itemData(ui->FileFormatCB->currentIndex()).toInt();
         FileFormat=QString(FORMATDEF[OutputFileFormat].LongName)+" (*."+QString(FORMATDEF[OutputFileFormat].FileExtension)+")";
     } else {
-        QString Device=ui->DeviceModelCB->currentText();
-        int i=0;
-        while ((i<Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel.count())&&(Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->DeviceName!=Device)) i++;
-        if (i<Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel.count()) {
-            FileFormat=QString(FORMATDEF[Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->FileFormat].LongName)+" (*."+
-                    QString(FORMATDEF[Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->FileFormat].FileExtension)+")";
+        if (ExportMode==MODE_LOSSLESS) {
+            // For Lossless, OutputFileFormat is 2 : matroska
+            FileFormat=QString(FORMATDEF[2].LongName)+" (*."+QString(FORMATDEF[2].FileExtension)+")";
+        } else {
+            QString Device=ui->DeviceModelCB->currentText();
+            int i=0;
+            while ((i<Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel.count())&&(Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->DeviceName!=Device)) i++;
+            if (i<Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel.count()) {
+                FileFormat=QString(FORMATDEF[Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->FileFormat].LongName)+" (*."+
+                        QString(FORMATDEF[Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->FileFormat].FileExtension)+")";
+            }
         }
     }
     //QString Path=QFileInfo(ui->DestinationFilePath->text()).absolutePath();
@@ -418,18 +427,22 @@ void DlgRenderVideo::InitVideoBitRateCB(int ChangeIndex) {
     if (ExportMode==MODE_LOSSLESS) {
         QString Text="Format=\tMKV\nVideo=\tx264 lossless";
         int ImgSize=ImageSize=ui->ImageSizeCombo->itemData(ui->ImageSizeCombo->currentIndex()).toInt();
-        int ExtendH   =0;
-        int ExtendV   =0;
-        int W=DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Width;
-        int H=DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Height;
+        int ExtendH =0;
+        int ExtendV =DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Extend;
+        int W       =DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Width;
+        int H       =DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Height;
         Text=Text+QString("-%1").arg(W)+"x"+QString("%1").arg(H);
         if (ExtendH>0) Text=Text+"+PADLEFT:"+QString("%1").arg(ExtendH/2)+"+PADRIGHT:"+QString("%1").arg(ExtendH-ExtendH/2);
-        if (ExtendV>0) Text=Text+"+PADTOP:"+QString("%1").arg(ExtendV/2)+"+PADBOTTOM:"+QString("%1").arg(ExtendV-ExtendV/2);
+        if (ExtendV>0) {
+            if (!ui->HTML5UPVideoCB->isChecked())   Text=Text+"+PADTOP:"+QString("%1").arg(ExtendV/2)+"+PADBOTTOM:"+QString("%1").arg(ExtendV-ExtendV/2);
+                else                                Text=Text+"+PADBOTTOM:"+QString("%1").arg(ExtendV);
+        }
         if (ui->IncludeSoundCB->isChecked()) Text=Text+"\nAudio=\tFLAC";
         ui->RenderFormatText->setText(Text);
         AdjustDestinationFile();
     } else {
         ui->VideoBitRateCB->clear();
+        int Standard    =ui->StandardCombo->currentIndex();
         int CurrentCodec=ui->VideoFormatCB->currentIndex();
         int CurrentSize =ui->ImageSizeCombo->itemData(ui->ImageSizeCombo->currentIndex()).toInt();
         if (CurrentCodec>=0) {
@@ -469,7 +482,7 @@ void DlgRenderVideo::InitVideoBitRateCB(int ChangeIndex) {
                     IsFindBitRate=true;
                 }
             }
-            if (!IsFindBitRate) ui->VideoBitRateCB->setCurrentIndex(ui->VideoBitRateCB->findText(VIDEOCODECDEF[CurrentCodec].DefaultBitrate[CurrentSize]));
+            if (!IsFindBitRate) ui->VideoBitRateCB->setCurrentIndex(ui->VideoBitRateCB->findText(VIDEOCODECDEF[CurrentCodec].DefaultBitrate[Standard][CurrentSize]));
             ui->VideoBitRateCB->setEnabled(ui->VideoBitRateCB->count()>1);
         } else ui->VideoBitRateCB->setEnabled(false);
     }
@@ -507,9 +520,9 @@ void DlgRenderVideo::InitAudioBitRateCB(int ChangeIndex) {
         }
         for (int i=0;i<List.count();i++) for (int j=0;j<List.count()-1;j++) {
             QString NameA=List[j];      if (NameA.endsWith("k")) NameA=NameA.left(NameA.length()-1);
-            int     NumA=NameA.toInt();
+            double  NumA=NameA.toDouble();
             QString NameB=List[j+1];    if (NameB.endsWith("k")) NameB=NameB.left(NameB.length()-1);
-            int     NumB=NameB.toInt();
+            double  NumB=NameB.toDouble();
             if (NumA>NumB) List.swap(j,j+1);
         }
         for (int i=0;i<List.count();i++) {
@@ -579,6 +592,11 @@ void DlgRenderVideo::s_IncludeSound() {
 
 //====================================================================================================================
 
+void DlgRenderVideo::s_HTML5UPVideo() {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgRenderVideo::s_HTML5UPVideo");
+    s_DeviceModelCB(0);
+}
+
 void DlgRenderVideo::s_DeviceModelCB(int) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:DlgRenderVideo::s_DeviceModelCB");
 
@@ -591,17 +609,31 @@ void DlgRenderVideo::s_DeviceModelCB(int) {
         Text=Text+VIDEOCODECDEF[Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->VideoCodec].LongName;
         int ImgSize=Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->ImageSize;
         int ExtendH   =0;
-        int ExtendV   =0;
-        int W=DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Width;
-        int H=DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Height;
+        int ExtendV   =DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Extend*2;
+        int W         =DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Width;
+        int H         =DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].Height;
         Text=Text+QString("-%1").arg(W)+"x"+QString("%1").arg(H);
         if (ExtendH>0) Text=Text+"+PADLEFT:"+QString("%1").arg(ExtendH/2)+"+PADRIGHT:"+QString("%1").arg(ExtendH-ExtendH/2);
-        if (ExtendV>0) Text=Text+"+PADTOP:"+QString("%1").arg(ExtendV/2)+"+PADBOTTOM:"+QString("%1").arg(ExtendV-ExtendV/2);
+        if (ExtendV>0) {
+            ui->HTML5UPVideoCB->setVisible(true);
+            ui->HTML5UPVideoLabel->setVisible(true);
+            if (!ui->HTML5UPVideoCB->isChecked()) Text=Text+"+PADTOP:"+QString("%1").arg(ExtendV/2)+"+PADBOTTOM:"+QString("%1").arg(ExtendV-ExtendV/2);
+                else Text=Text+"+PADBOTTOM:"+QString("%1").arg(ExtendV);
+        } else {
+            ui->HTML5UPVideoCB->setVisible(false);
+            ui->HTML5UPVideoLabel->setVisible(false);
+        }
 
+        QString FPS=DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].dFPS==24?"24 FPS":
+                    DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].dFPS==25?"25 FPS":
+                    DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].dFPS==24000L/1001L?"23.98 FPS":
+                    DefImageFormat[Standard][Diaporama->ImageGeometry][ImgSize].dFPS==30000L/1001L?"29.97 FPS":
+                    "";
+                                                                                          ;
         QString VideoBitRateStr=QString("%1").arg(Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->VideoBitrate); if (VideoBitRateStr.endsWith("000")) VideoBitRateStr=VideoBitRateStr.left(VideoBitRateStr.length()-3)+"k";
         QString AudioBitRateStr=QString("%1").arg(Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->AudioBitrate); if (AudioBitRateStr.endsWith("000")) AudioBitRateStr=AudioBitRateStr.left(AudioBitRateStr.length()-3)+"k";
 
-        Text=Text+"-"+VideoBitRateStr+"b/s";
+        Text=Text+"-"+FPS+"-"+VideoBitRateStr+"b/s";
         if (ui->IncludeSoundCB->isChecked()) Text=Text+"\nAudio=\t"+AUDIOCODECDEF[Diaporama->ApplicationConfig->DeviceModelList.RenderDeviceModel[i]->AudioCodec].LongName+"-"+AudioBitRateStr+"b/s";
         ui->RenderFormatText->setText(Text);
 
@@ -614,9 +646,7 @@ void DlgRenderVideo::s_DeviceModelCB(int) {
 // Video codec part
 bool DlgRenderVideo::ComputeVideoPart(QString &vCodec) {
     bool    Continue=true;
-    #ifdef LIBAV_08
     bool    isAVCONV=(Diaporama->ApplicationConfig->BinaryEncoderPath=="avconv");
-    #endif
 
     switch (VIDEOCODECDEF[VideoCodecIndex].FFD_VCODEC) {
 
@@ -658,18 +688,16 @@ bool DlgRenderVideo::ComputeVideoPart(QString &vCodec) {
             Preset="-fpre \""+Preset+"libx264-hq.ffpreset\"";
             #endif
             #ifdef LIBAV_08
-            Preset="-preset veryfast -refs:0 3";
-            //if (isAVCONV)   Preset="-preset veryfast -refs:0 3";
-            //    else        Preset="-preset veryfast -x264opts ref=3";
+            if (isAVCONV)   Preset="-preset veryfast -refs:0 3";
+                else        Preset="-preset veryfast -x264opts ref=3";
             #endif
         } else if (VIDEOCODECDEF[VideoCodecIndex].FFD_VCODEC==VCODEC_H264PQ) {
             #ifdef LIBAV_07
             Preset="-fpre \""+Preset+"libx264-pq.ffpreset\"";
             #endif
             #ifdef LIBAV_08
-            Preset="-preset veryfast -profile:v baseline -tune:v fastdecode";
-            //if (isAVCONV)   Preset="-preset veryfast -profile:v baseline -tune:v fastdecode";
-            //    else        Preset="-preset veryfast -x264opts level=1.3:no-cabac:vbv-bufsize=768:vbv-maxrate=768";
+            if (isAVCONV)   Preset="-preset veryfast -profile:v baseline -tune:v fastdecode";
+                else        Preset="-preset veryfast -x264opts ref=3 -profile:v baseline -tune:v fastdecode";
             #endif
         } else if (VIDEOCODECDEF[VideoCodecIndex].FFD_VCODEC==VCODEC_X264LL) {
             #ifdef LIBAV_07
@@ -697,6 +725,7 @@ bool DlgRenderVideo::ComputeVideoPart(QString &vCodec) {
 // Audio codec part
 bool DlgRenderVideo::ComputeAudioPart(QString &aCodec) {
     bool    Continue=true;
+    bool    isAVCONV=(Diaporama->ApplicationConfig->BinaryEncoderPath=="avconv");
 
     if (!ui->IncludeSoundCB->isChecked()) {
         aCodec="-an";
@@ -714,10 +743,14 @@ bool DlgRenderVideo::ComputeAudioPart(QString &aCodec) {
                 aCodec=QString("-acodec flac");
                 break;
 
+            case CODEC_ID_AC3:
+                if (isAVCONV) aCodec=QString("-acodec %1 -sample_fmt:1 flt -ab %2").arg(AUDIOCODECDEF[AudioCodecIndex].ShortName).arg(AudioBitRate);
+                    else      aCodec=QString("-acodec %1 -ab %2").arg(AUDIOCODECDEF[AudioCodecIndex].ShortName).arg(AudioBitRate);
+                break;
+
             case CODEC_ID_MP2:
             case CODEC_ID_MP3:
             case CODEC_ID_AAC:
-            case CODEC_ID_AC3:
             case CODEC_ID_VORBIS:
             case CODEC_ID_AMR_WB:
             case CODEC_ID_AMR_NB:
@@ -754,10 +787,8 @@ bool DlgRenderVideo::ComputeAudioPart(QString &aCodec) {
 //====================================================================================================================
 
 // Audio codec part
-bool DlgRenderVideo::ComputeTAGPart(QString &aTAG) {
-    #ifdef LIBAV_08
+bool DlgRenderVideo::ComputeTAGPart(QString &aTAG,bool WithChapters) {
     bool    isAVCONV=(Diaporama->ApplicationConfig->BinaryEncoderPath=="avconv");
-    #endif
 
     // Create metadata temp file
     TempMETAFileName=AdjustDirForOS(QFileInfo(OutputFileName).absolutePath());
@@ -788,7 +819,7 @@ bool DlgRenderVideo::ComputeTAGPart(QString &aTAG) {
         out<<QString("language="+Language+"\n");
         out<<QString("creation_time="+QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss")+"\n");   // ISO 8601 format
 
-        for (int i=FromSlide;i<=ToSlide;i++) if ((i==FromSlide)||(Diaporama->List[i]->StartNewChapter)) {
+        if (WithChapters) for (int i=FromSlide;i<=ToSlide;i++) if ((i==FromSlide)||(Diaporama->List[i]->StartNewChapter)) {
             int NextChapter=i+1;
             qlonglong Start   =Diaporama->GetObjectStartPosition(i)+(i>FromSlide?Diaporama->List[i]->GetTransitDuration():0)-Diaporama->GetObjectStartPosition(FromSlide);
             qlonglong Duration=Diaporama->List[i]->GetDuration()-(i>FromSlide?Diaporama->List[i]->GetTransitDuration():0);
@@ -797,11 +828,12 @@ bool DlgRenderVideo::ComputeTAGPart(QString &aTAG) {
                 NextChapter++;
                 if (NextChapter<ToSlide) Duration=Duration-Diaporama->List[NextChapter]->GetTransitDuration();
             }
-            out<<"[CHAPTER]\n";                                         // Write Chapter header
-            out<<"TIMEBASE=1/1000\n";                                   // Timebase
-            out<<"START="+QString("%1").arg(Start)+"\n";                // Start position in ms
-            out<<"END="+QString("%1").arg(Start+Duration)+"\n";         // End position in ms
-            out<<"TITLE="+Diaporama->List[i]->SlideName+"\n";           // Title
+            out<<"[CHAPTER]\n";                                                         // Write Chapter header
+            out<<"TIMEBASE=1/1000000\n";                                                // Timebase
+            out<<"START="+QString("%1").arg(Start*1000)+"\n";                           // Start position in ms
+            out<<"END="+QString("%1").arg((Start+Duration)*1000)+"\n";                  // End position in ms
+            if (isAVCONV)   out<<"TITLE="+Diaporama->List[i]->SlideName+"\n";           // Title
+                else        out<<"title="+Diaporama->List[i]->SlideName+"\n";           // Title
         }
 
         File.close();
@@ -810,11 +842,12 @@ bool DlgRenderVideo::ComputeTAGPart(QString &aTAG) {
         aTAG=" -i \""+TempMETAFileName+"\"  -map_metadata g:0 -map_chapters 0";
         #endif
         #ifdef LIBAV_08
-        if (isAVCONV) aTAG=" -i \""+TempMETAFileName+"\"  -map_metadata:g "+(ui->IncludeSoundCB->isChecked()?"2":"1")+" -map_chapters "+(ui->IncludeSoundCB->isChecked()?"2":"1");
-            aTAG=" -i \""+TempMETAFileName+"\"  -map_metadata:g 0 -map_chapters 0"; // For ffmpeg, mapping is to destination file (for avconv is to source !)
+        if (isAVCONV) aTAG=" -i \""+TempMETAFileName+"\" -map_metadata "+(ui->IncludeSoundCB->isChecked()?"2":"1")+":g -map_chapters "+(ui->IncludeSoundCB->isChecked()?"2":"1");
+            else      aTAG=" -i \""+TempMETAFileName+"\" -map_metadata:g 0:g -map_chapters "+(ui->IncludeSoundCB->isChecked()?"2":"1"); // For ffmpeg, mapping is to destination file (for avconv is to source !)
         #endif
         return true;
     } else return false;
+
 }
 
 //====================================================================================================================
@@ -826,6 +859,7 @@ void DlgRenderVideo::DoAccept() {
     cDiaporamaObjectInfo    *Frame          =NULL;
     QString                 vCodec="";
     QString                 aCodec="";
+    QString                 StreamFormat="";
     QString                 TAG="";
     QString                 ffmpegCommand;
     QProcess                Process;
@@ -897,7 +931,13 @@ void DlgRenderVideo::DoAccept() {
             }
             AudioCodecIndex=ui->AudioFormatCB->itemData(AudioCodecIndex).toInt();
             BitRate=ui->AudioBitRateCB->currentText();
-            if (BitRate.endsWith("k")) BitRate=BitRate.left(BitRate.length()-1)+"000";
+            if (BitRate.endsWith("k")) {
+                if (BitRate.contains(".")) {
+                    BitRate=BitRate.left(BitRate.length()-1);
+                    double Value=BitRate.toDouble()*1000;
+                    BitRate=QString("%1").arg(int(Value));
+                } else BitRate=BitRate.left(BitRate.length()-1)+"000";
+            }
             AudioBitRate=BitRate.toInt();
             ExtendV =DefImageFormat[Standard][Diaporama->ImageGeometry][ImageSize].Extend*2;
 
@@ -992,6 +1032,8 @@ void DlgRenderVideo::DoAccept() {
         ui->ProjectPropertiesBt->setEnabled(false);
         ui->HelpBT->setEnabled(false);
 
+        ui->CancelBt->setToolTip(QApplication::translate("DlgRenderVideo","Stop rendering process and exit dialog box"));
+
         //**********************************************************************************************************************************
         // 1st step encoding : produce WAV file with sound
         //**********************************************************************************************************************************
@@ -1036,14 +1078,15 @@ void DlgRenderVideo::DoAccept() {
 
         Continue=Continue && ComputeVideoPart(vCodec);
         Continue=Continue && ComputeAudioPart(aCodec);
+        if (QString(FORMATDEF[OutputFileFormat].ShortName)=="mpeg") StreamFormat=" -f mpegts";
 
         #ifdef LIBAV_TAGCHAPTERS
-        Continue=Continue && ComputeTAGPart(TAG);
+        Continue=Continue && ComputeTAGPart(TAG,(OutputFileFormat!=2)||(ExportMode==MODE_LOSSLESS));
         #endif
 
         // Construct ffmpeg command line
         if (Continue) {
-            ToLog(LOGMSG_INFORMATION,QApplication::translate("DlgRenderVideo","Start avconv encoder"));
+            ToLog(LOGMSG_INFORMATION,QApplication::translate("DlgRenderVideo","Start encoder"));
 
             #ifdef Q_OS_WIN
             ffmpegCommand="\""+Diaporama->ApplicationConfig->BinaryEncoderPath+"\"";
@@ -1057,10 +1100,15 @@ void DlgRenderVideo::DoAccept() {
                 #ifdef LIBAV_07
                 " -timestamp now"+
                 #endif
-                QString(" -dframes %1 %2 -r %3 ").arg(NbrFrame).arg(vCodec).arg(DefImageFormat[Standard][Diaporama->ImageGeometry][ImageSize].FPS)+
+                QString(" -dframes %1%2 %3 -r %4 ").arg(NbrFrame).arg(StreamFormat).arg(vCodec).arg(DefImageFormat[Standard][Diaporama->ImageGeometry][ImageSize].FPS)+
                 //(UpdateWidth!=W?QString(" -s %1x%2").arg(UpdateWidth).arg(H+ExtendV):"")+
                 #ifdef LIBAV_08
-                " -sws_flags bicubic "+
+                    #if (LIBAVCODEC_VERSION_MAJOR>=54)
+                        ((Diaporama->ApplicationConfig->BinaryEncoderPath=="avconv")?QString(" -filter:v scale=%1:%2:flags=bicubic ").arg(DefImageFormat[Standard][Diaporama->ImageGeometry][ImageSize].Width).arg(DefImageFormat[Standard][Diaporama->ImageGeometry][ImageSize].Height):
+                    #else
+                        (
+                    #endif
+                      " -sws_flags bicubic ")+
                 #endif
                 QString("%1 -aspect %2:%3").arg(aCodec).arg(GeoW).arg(GeoH);
 
@@ -1069,6 +1117,12 @@ void DlgRenderVideo::DoAccept() {
                 ffmpegCommand=ffmpegCommand+" -threads "+QString("%1").arg(getCpuCount()-1);
 
             ffmpegCommand=ffmpegCommand+" \""+OutputFileName+"\"";
+
+            #ifdef Q_OS_WIN
+            ffmpegCommand=ffmpegCommand.replace("30000/1001","29.97");
+            ffmpegCommand=ffmpegCommand.replace("24000/1001","23.976");
+            #endif
+
             ToLog(LOGMSG_INFORMATION,ffmpegCommand);
 
             ffmpegCommand=AdjustDirForOS(ffmpegCommand);
@@ -1080,7 +1134,7 @@ void DlgRenderVideo::DoAccept() {
             Process.start(ffmpegCommand,QIODevice::Append|QIODevice::ReadWrite);                 // Start command
             if (!Process.waitForStarted()) {
                 CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),
-                                      QApplication::translate("DlgRenderVideo","Error starting avconv","Error message")+"\n"+ffmpegCommand,
+                                      QApplication::translate("DlgRenderVideo","Error starting encoder","Error message")+"\n"+ffmpegCommand,
                                       QMessageBox::Close);
                 Continue=false;
             }
@@ -1104,6 +1158,7 @@ void DlgRenderVideo::DoAccept() {
                         if (AdjustedDuration<33) AdjustedDuration=33;   // Not less than 1/30 sec
                         ColumnStart=Diaporama->GetObjectStartPosition(Column);
                         if (Column<Diaporama->List.count()) ui->SlideProgressBar->setMaximum(int(double(AdjustedDuration)/(FPS/double(1000)))-1);
+                        Diaporama->CloseUnusedLibAv(Column);
                     }
                     RefreshDisplay =true;
                 } else RefreshDisplay =(LastCheckTime.msecsTo(QTime::currentTime())>=1000);    // Refresh display only one time per second
@@ -1129,8 +1184,8 @@ void DlgRenderVideo::DoAccept() {
                 Frame=new cDiaporamaObjectInfo(PreviousFrame,Position,Diaporama,(FPS/1000));
 
                 // Prepare frame with correct W and H
-                Diaporama->LoadSources(Frame,double(H)/double(1080),W,H,false,true);        // Load source images
-                Diaporama->DoAssembly(Frame,W,H);                                           // Make final assembly
+                Diaporama->LoadSources(Frame,double(H)/double(1080),W,H,false,true);                                        // Load source images
+                Diaporama->DoAssembly(ComputePCT(Frame->CurrentObject?Frame->CurrentObject->GetSpeedWave():0,Frame->TransitionPCTDone),Frame,W,H); // Make final assembly
 
                 // Give time to interface!
                 QApplication::processEvents();
@@ -1148,22 +1203,23 @@ void DlgRenderVideo::DoAccept() {
                     ToSave->fill(0);
                     QPainter P;
                     P.begin(ToSave);
-                    P.drawImage(ExtendH/2,ExtendV/2,*Frame->RenderedImage);
+                    if (!ui->HTML5UPVideoCB->isChecked())   P.drawImage(ExtendH/2,ExtendV/2,*Frame->RenderedImage);
+                        else                                P.drawImage(ExtendH/2,0,*Frame->RenderedImage);
                     P.end();
                 }
 
                 // Save image to the pipe
                 if (!ToSave->save(&Process,"PPM",-1)) {
-                    CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Error sending image to ffmpeg","Error message"),QMessageBox::Close);
+                    CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Error sending image to encoder","Error message"),QMessageBox::Close);
                     Continue=false;
                 }
 
                 if (ToSave!=Frame->RenderedImage) delete ToSave;
 
-                // Wait until ffmpeg processed the frame
+                // Wait until encoder processed the frame
                 while (Continue &&(Process.bytesToWrite()>0)) {
                     if (!Process.waitForBytesWritten()) {
-                        CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","avconv error","Error message"),QMessageBox::Close);
+                        CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Encoder error","Error message"),QMessageBox::Close);
                         Continue=false;
                     }
                     // Give time to interface!
@@ -1199,12 +1255,12 @@ void DlgRenderVideo::DoAccept() {
             ui->SlideProgressBar->setValue(ui->SlideProgressBar->maximum());
             ui->TotalProgressBar->setValue(NbrFrame);
 
-            if (!Process.waitForFinished(30000)) { // 30 sec max to close ffmpeg
-                CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Error during avconv process","Error message"),QMessageBox::Close);
+            if (!Process.waitForFinished(30000)) { // 30 sec max to close encoder
+                CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Error closing encoder","Error message"),QMessageBox::Close);
                 Process.terminate();
                 Continue=false;
             } else if (Process.exitStatus()!=QProcess::NormalExit) {
-              CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Error exiting avconv","Error message"),QMessageBox::Close);
+              CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Error","Error message"),QApplication::translate("DlgRenderVideo","Error exiting encoder","Error message"),QMessageBox::Close);
               Continue=false;
             }
         }
@@ -1425,7 +1481,7 @@ bool DlgRenderVideo::WriteTempAudioFile(QString TempWAVFileName,int FromSlide) {
             Diaporama->LoadSources(Frame,0,0,0,false,true);
 
             // Give time to interface!
-            QApplication::processEvents();
+            while ((ThreadWrite.isRunning())&&(!StopProcessWanted)) QApplication::processEvents();  //ThreadWrite.waitForFinished();
 
             // Calc number of packet to mix
             int MaxPacket=Frame->CurrentObject_MusicTrack->List.count();
@@ -1439,7 +1495,6 @@ bool DlgRenderVideo::WriteTempAudioFile(QString TempWAVFileName,int FromSlide) {
                 WriteWAV.RenderMusic.MixAppendPacket(Frame->CurrentObject_MusicTrack->DetachFirstPacket(),(Frame->CurrentObject_SoundTrackMontage!=NULL)?Frame->CurrentObject_SoundTrackMontage->DetachFirstPacket():NULL);
 
             // Write audio frame to disk
-            if (ThreadWrite.isRunning()) ThreadWrite.waitForFinished();
             ThreadWrite.setFuture(QtConcurrent::run(this,&DlgRenderVideo::WriteRenderedMusicToDisk,&WriteWAV,&Continue));
 
             QApplication::processEvents();  // Give time to interface!
@@ -1451,10 +1506,10 @@ bool DlgRenderVideo::WriteTempAudioFile(QString TempWAVFileName,int FromSlide) {
             Frame =NULL;
 
             // Stop the process if error occur or user ask to stop
-            Continue=Continue && !StopProcessWanted;;
+            Continue=Continue && !StopProcessWanted;
         }
 
-        if (ThreadWrite.isRunning()) ThreadWrite.waitForFinished();
+        while (ThreadWrite.isRunning()) QApplication::processEvents();  //ThreadWrite.waitForFinished();
 
         // Write de trailer
         if ((Continue)&&(av_write_trailer(WriteWAV.OutputFormatContext)!=0)) {
@@ -1475,7 +1530,10 @@ bool DlgRenderVideo::WriteTempAudioFile(QString TempWAVFileName,int FromSlide) {
         if (WriteWAV.OutputFormatContext->pb) avio_close(WriteWAV.OutputFormatContext->pb);                                   // close the file
         if (WriteWAV.OutputFormatContext->streams[0]) {
             avcodec_close(WriteWAV.AudioStream->codec);                                                              // close codec
-            if (WriteWAV.OutputFormatContext->streams[0]->codec) av_freep(&WriteWAV.OutputFormatContext->streams[0]->codec);  // free the audiostream
+            if (WriteWAV.OutputFormatContext->streams[0]->codec) {
+                av_free(WriteWAV.OutputFormatContext->streams[0]->codec);  // free the audiostream
+                WriteWAV.OutputFormatContext->streams[0]->codec=NULL;
+            }
         }
         av_free(WriteWAV.OutputFormatContext);                                                                       // free the container
     }
@@ -1487,36 +1545,87 @@ void DlgRenderVideo::WriteRenderedMusicToDisk(sWriteWAV *WriteWAV,bool *Continue
    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgRenderVideo::WriteTempAudioFile");
 
     // Flush audio frame
-    AVPacket pkt;
     while (WriteWAV->RenderMusic.List.count()>0) {
         int16_t *PacketSound=WriteWAV->RenderMusic.DetachFirstPacket();
         if (PacketSound==NULL) {
             PacketSound=(int16_t *)av_malloc(WriteWAV->RenderMusic.SoundPacketSize+4);
             memset(PacketSound,0,WriteWAV->RenderMusic.SoundPacketSize);
         }
-        int out_size= avcodec_encode_audio(WriteWAV->AudioCodecContext,WriteWAV->audio_outbuf,WriteWAV->RenderMusic.SoundPacketSize,(short int *)PacketSound);
-        if (out_size>0) {
-            av_init_packet(&pkt);
 
-            if ((WriteWAV->AudioCodecContext->coded_frame!=NULL)&&(WriteWAV->AudioCodecContext->coded_frame->pts!=int64_t(INT64_C(0x8000000000000000))))
-                pkt.pts=av_rescale_q(WriteWAV->AudioCodecContext->coded_frame->pts,WriteWAV->AudioCodecContext->time_base,WriteWAV->AudioStream->time_base);
+        #if FF_API_OLD_ENCODE_AUDIO
 
-            if ((WriteWAV->AudioCodecContext->coded_frame!=NULL)&&(WriteWAV->AudioCodecContext->coded_frame->key_frame))
-                pkt.flags|=AV_PKT_FLAG_KEY;
+            // Init frame
+            AVFrame *frame=avcodec_alloc_frame();
+            if (frame->extended_data!=frame->data) {
+                av_free(frame->extended_data);
+                frame->extended_data=NULL;
+            }
+            avcodec_get_frame_defaults(frame);
+            frame->nb_samples=WriteWAV->RenderMusic.SoundPacketSize/(WriteWAV->AudioCodecContext->channels*av_get_bytes_per_sample(WriteWAV->AudioCodecContext->sample_fmt));
 
-            pkt.stream_index=WriteWAV->AudioStream->index;
-            pkt.data        =WriteWAV->audio_outbuf;
-            pkt.size        =out_size;
+            // fill buffer
+            if (avcodec_fill_audio_frame(frame,WriteWAV->AudioCodecContext->channels,WriteWAV->AudioCodecContext->sample_fmt,(const uint8_t*)PacketSound,WriteWAV->RenderMusic.SoundPacketSize,1)>=0) {
 
-            // write the compressed frame in the media file
-            if (av_interleaved_write_frame(WriteWAV->OutputFormatContext,&pkt)!=0) {
-                CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error while writing audio frame!");
+                // Init packet
+                AVPacket pkt;
+                av_init_packet(&pkt);
+                pkt.data = NULL;
+                pkt.size = 0;
+
+                int got_packet=0;
+                if (avcodec_encode_audio2(WriteWAV->AudioCodecContext,&pkt,frame,&got_packet)<0) {
+
+                    CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error encoding sound!");
+                    *Continue=false;
+
+                } else {
+
+                    if ((WriteWAV->AudioCodecContext->coded_frame!=NULL)&&(WriteWAV->AudioCodecContext->coded_frame->pts!=int64_t(INT64_C(0x8000000000000000))))
+                        pkt.pts=av_rescale_q(WriteWAV->AudioCodecContext->coded_frame->pts,WriteWAV->AudioCodecContext->time_base,WriteWAV->AudioStream->time_base);
+
+                    if ((WriteWAV->AudioCodecContext->coded_frame!=NULL)&&(WriteWAV->AudioCodecContext->coded_frame->key_frame))
+                        pkt.flags|=AV_PKT_FLAG_KEY;
+
+                    pkt.stream_index=WriteWAV->AudioStream->index;
+
+                    // write the compressed frame in the media file
+                    if (av_interleaved_write_frame(WriteWAV->OutputFormatContext,&pkt)!=0) {
+                        CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error while writing audio frame!");
+                        *Continue=false;
+                    }
+                }
+            } else {
+                CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error encoding sound!");
                 *Continue=false;
             }
-        } else if (out_size<0) {
-            CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error encoding sound!");
-            *Continue=false;
-        }
+            av_free(frame);
+
+        #else
+            int out_size= avcodec_encode_audio(WriteWAV->AudioCodecContext,WriteWAV->audio_outbuf,WriteWAV->RenderMusic.SoundPacketSize,(short int *)PacketSound);
+            if (out_size>0) {
+                AVPacket pkt;
+                av_init_packet(&pkt);
+
+                if ((WriteWAV->AudioCodecContext->coded_frame!=NULL)&&(WriteWAV->AudioCodecContext->coded_frame->pts!=int64_t(INT64_C(0x8000000000000000))))
+                    pkt.pts=av_rescale_q(WriteWAV->AudioCodecContext->coded_frame->pts,WriteWAV->AudioCodecContext->time_base,WriteWAV->AudioStream->time_base);
+
+                if ((WriteWAV->AudioCodecContext->coded_frame!=NULL)&&(WriteWAV->AudioCodecContext->coded_frame->key_frame))
+                    pkt.flags|=AV_PKT_FLAG_KEY;
+
+                pkt.stream_index=WriteWAV->AudioStream->index;
+                pkt.data        =WriteWAV->audio_outbuf;
+                pkt.size        =out_size;
+
+                // write the compressed frame in the media file
+                if (av_interleaved_write_frame(WriteWAV->OutputFormatContext,&pkt)!=0) {
+                    CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error while writing audio frame!");
+                    *Continue=false;
+                }
+            } else if (out_size<0) {
+                CustomMessageBox(this,QMessageBox::Critical,QApplication::translate("DlgRenderVideo","Render video"),"Error encoding sound!");
+                *Continue=false;
+            }
+        #endif
         av_free(PacketSound);
     }
 }
