@@ -62,6 +62,10 @@ void cBlockTableItemDelegate::paint(QPainter *Painter,const QStyleOptionViewItem
     if ((ParentTable->CompositionList==NULL)||(index.row()>=ParentTable->rowCount())||(index.column()>=ParentTable->columnCount())||(index.row()>=ParentTable->CompositionList->List.count())) return;
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
+    // Display adjustement
+    int     FontFactor=((((cApplicationConfig *)ParentTable->ApplicationConfig)->TimelineHeight-TIMELINEMINHEIGH)/20+1)*10;
+    int     RowHeight =48+((((cApplicationConfig *)ParentTable->ApplicationConfig)->TimelineHeight-TIMELINEMINHEIGH)/20+1)*3;
+
     if (!ParentTable->CompositionList->List[index.row()]->IsVisible) Painter->setOpacity(0.5);
 
 
@@ -73,25 +77,49 @@ void cBlockTableItemDelegate::paint(QPainter *Painter,const QStyleOptionViewItem
 
     if (MediaFile!=NULL) {
 
-        QImage *RenderImage=(ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Image!=NULL)?ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Image->ImageAt(true,NULL):
-                            (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video!=NULL)?ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video->ImageAt(true,0,0,NULL,1,false,NULL,false):
+        int Position=0;
+        // Compute position of video
+        if (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video)
+            for (int i=0;i<ParentTable->CurrentShotNbr;i++)
+                for (int j=0;j<ParentTable->CurrentSlide->List[i]->ShotComposition.List.count();j++)
+            if (ParentTable->CurrentSlide->List[i]->ShotComposition.List[j]->IndexKey==ParentTable->CompositionList->List[index.row()]->IndexKey) {
+                if (ParentTable->CurrentSlide->List[i]->ShotComposition.List[j]->IsVisible) Position+=ParentTable->CurrentSlide->List[i]->StaticDuration;
+        }
+
+
+        QImage *RenderImage=(ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Image!=NULL)?ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Image->ImageAt(true):
+                            (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video!=NULL)?ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video->ImageAt(true,Position,QTime(0,0,0,0).msecsTo(ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video->StartPos),NULL,ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Deinterlace,1,false,false):
                             NULL;
 
         if (RenderImage!=NULL) {
-            Icon=(RenderImage->width()>RenderImage->height())?RenderImage->scaledToWidth(48):RenderImage->scaledToHeight(48);
+            // Create square workspace image
+            qreal   maxw,maxh,minw,minh,x1,x2,x3,x4,y1,y2,y3,y4;
+            QImage  *NewRenderImage=ParentTable->CompositionList->List[index.row()]->BackgroundBrush->ImageToWorkspace(RenderImage,RowHeight,maxw,maxh,minw,minh,x1,x2,x3,x4,y1,y2,y3,y4);
+            QRectF  CurSelRect     =QRectF(ParentTable->CompositionList->List[index.row()]->BackgroundBrush->X*RowHeight,
+                                           ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Y*RowHeight,
+                                           ParentTable->CompositionList->List[index.row()]->BackgroundBrush->ZoomFactor*RowHeight,
+                                           ParentTable->CompositionList->List[index.row()]->BackgroundBrush->ZoomFactor*ParentTable->CompositionList->List[index.row()]->BackgroundBrush->AspectRatio*RowHeight);
+            ParentTable->CompositionList->List[index.row()]->BackgroundBrush->ApplyMaskToImageToWorkspace(NewRenderImage,CurSelRect,ParentTable->CompositionList->List[index.row()]->BackgroundForm,
+                                                                                                          ParentTable->CompositionList->List[index.row()]->BackgroundBrush->GetCurrentFramingStyle(ParentTable->ProjectGeometry));
+
+            // Create icon
+            //Icon=(NewRenderImage->width()>NewRenderImage->height())?NewRenderImage->scaledToWidth(RowHeight):NewRenderImage->scaledToHeight(RowHeight);
+            Icon=NewRenderImage->copy();
             delete RenderImage;
+            delete NewRenderImage;
         }
 
     } else Icon=ParentTable->TextIcon.copy();
 
-    int         IconHeight  =48;
-    int         IconWidth   =48+16;
+    int         IconHeight  =RowHeight;
+    int         IconWidth   =RowHeight+16;
     int         addX        =(IconHeight-(!Icon.isNull()?Icon.width():0))/2;
     int         addY        =(IconHeight-(!Icon.isNull()?Icon.height():0))/2;
     QFont       font;
     QTextOption OptionText;
     QPen        Pen;
 
+
     if ((ParentTable->CurrentShotNbr>0)&&(ParentTable->CompositionList->List[index.row()]->SameAsPrevShot))
         Painter->fillRect(QRect(option.rect.x(),option.rect.y(),option.rect.width(),option.rect.height()),QColor(Qt::lightGray));
 
@@ -99,19 +127,24 @@ void cBlockTableItemDelegate::paint(QPainter *Painter,const QStyleOptionViewItem
     if (!Icon.isNull()) Painter->drawImage(QRectF(option.rect.x()+1+addX,option.rect.y()+1+addY,Icon.width(),Icon.height()),Icon);
 
     // Visible or not visible
-    Painter->drawImage(QRectF(option.rect.x()+1+48,option.rect.y()+1+32,16,16),QImage(ParentTable->CompositionList->List[index.row()]->IsVisible?ICON_VISIBLE_OK:ICON_VISIBLE_KO));
+    Painter->drawImage(QRectF(option.rect.x()+1+RowHeight,option.rect.y()+1+2*(RowHeight/3),16,16),QImage(ParentTable->CompositionList->List[index.row()]->IsVisible?ICON_VISIBLE_OK:ICON_VISIBLE_KO));
 
     // With same as previous shot ?
-    if (ParentTable->CurrentShotNbr>0) Painter->drawImage(QRectF(option.rect.x()+1+48,option.rect.y()+1,16,16),QImage(ParentTable->CompositionList->List[index.row()]->SameAsPrevShot?ICON_HAVELOCK:ICON_HAVENOLOCK));
+    if (ParentTable->CurrentShotNbr>0) Painter->drawImage(QRectF(option.rect.x()+1+RowHeight,option.rect.y()+1,16,16),QImage(ParentTable->CompositionList->List[index.row()]->SameAsPrevShot?ICON_HAVELOCK:ICON_HAVENOLOCK));
 
     // With sound ?
     if (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video!=NULL)
-        Painter->drawImage(QRectF(option.rect.x()+1+48,option.rect.y()+1+16,16,16),QImage((ParentTable->CompositionList->List[index.row()]->BackgroundBrush->SoundVolume!=0)?ICON_SOUND_OK:ICON_SOUND_KO));
+        Painter->drawImage(QRectF(option.rect.x()+1+RowHeight,option.rect.y()+1+RowHeight/3,16,16),QImage((ParentTable->CompositionList->List[index.row()]->BackgroundBrush->SoundVolume!=0)?ICON_SOUND_OK:ICON_SOUND_KO));
 
     // With filter ?
-    if (((ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Image!=NULL)&&(ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Image->BrushFileTransform.HaveFilter()))||
-       ((ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video!=NULL)&&(ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Video->BrushFileTransform.HaveFilter())))
-        Painter->drawImage(QRectF(option.rect.x()+1,option.rect.y()+24,24,24),QImage(ICON_HAVEFILTER));
+    if ((ParentTable->CompositionList->List[index.row()]->BackgroundBrush->GaussBlurSharpenSigma!=0)||
+        (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->QuickBlurSharpenSigma!=0)||
+        (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Desat!=0)||
+        (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Swirl!=0)||
+        (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->Implode!=0)||
+        (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->WaveAmp!=0)||
+        (ParentTable->CompositionList->List[index.row()]->BackgroundBrush->OnOffFilter!=0)
+       ) Painter->drawImage(QRectF(option.rect.x()+1,option.rect.y()+RowHeight/2,24,24),QImage(ICON_HAVEFILTER));
 
     // Setup default brush
     Painter->setBrush(Qt::NoBrush);
@@ -138,6 +171,13 @@ void cBlockTableItemDelegate::paint(QPainter *Painter,const QStyleOptionViewItem
         // First line
         font=QFont("Sans serif",9,QFont::Bold,QFont::StyleNormal);          // First line use bold
         Painter->setFont(font);
+        #ifdef Q_OS_WIN
+        font.setPointSizeF(double(110+FontFactor)/double(Painter->fontMetrics().boundingRect("0").height()));                  // Scale font
+        #else
+        font.setPointSizeF(double(120+FontFactor)/double(Painter->fontMetrics().boundingRect("0").height()));                  // Scale font
+        #endif
+        Painter->setFont(font);
+
         OptionText=QTextOption(Qt::AlignLeft|Qt::AlignVCenter);                     // Setup alignement
         OptionText.setWrapMode(QTextOption::NoWrap);                                // Setup word wrap text option
         Painter->drawText(QRectF(option.rect.x()+IconWidth+2+2,option.rect.y()+1,option.rect.width()-IconWidth-3-2,14),SummaryText[0],OptionText);
@@ -146,15 +186,27 @@ void cBlockTableItemDelegate::paint(QPainter *Painter,const QStyleOptionViewItem
         font=QFont("Sans serif",8,QFont::Normal,QFont::StyleNormal);
         font.setUnderline(false);
         Painter->setFont(font);
-        Painter->drawText(QRectF(option.rect.x()+IconWidth+2+2,option.rect.y()+1+(14+2),option.rect.width()-IconWidth-3-2,14),SummaryText[1],OptionText);
+        #ifdef Q_OS_WIN
+        font.setPointSizeF(double(100+FontFactor)/double(Painter->fontMetrics().boundingRect("0").height()));                  // Scale font
+        #else
+        font.setPointSizeF(double(100+FontFactor)/double(Painter->fontMetrics().boundingRect("0").height()));                  // Scale font
+        #endif
+        Painter->setFont(font);
+        Painter->drawText(QRectF(option.rect.x()+IconWidth+2+2,option.rect.y()+1+(RowHeight/3),option.rect.width()-IconWidth-3-2,14),SummaryText[1],OptionText);
 
         // Third line
-        Painter->drawText(QRectF(option.rect.x()+IconWidth+2+2,option.rect.y()+1+(14+2)*2,option.rect.width()-IconWidth-3-2,14),SummaryText[2],OptionText);
+        Painter->drawText(QRectF(option.rect.x()+IconWidth+2+2,option.rect.y()+1+(RowHeight/3)*2,option.rect.width()-IconWidth-3-2,14),SummaryText[2],OptionText);
 
     } else {
         font=QFont("Sans serif",8,QFont::Normal,QFont::StyleNormal);
         font.setUnderline(false);
         Painter->setFont(font);
+        #ifdef Q_OS_WIN
+        font.setPointSizeF(double(100+FontFactor)/double(Painter->fontMetrics().boundingRect("0").height()));                  // Scale font
+        #else
+        font.setPointSizeF(double(100+FontFactor)/double(Painter->fontMetrics().boundingRect("0").height()));                  // Scale font
+        #endif
+        Painter->setFont(font);
         OptionText=QTextOption(Qt::AlignLeft|Qt::AlignVCenter);                     // Setup alignement
         OptionText.setWrapMode(QTextOption::NoWrap);                                // Setup word wrap text option
         QTextDocument   TextDoc;
@@ -198,6 +250,7 @@ cCustomBlockTable::cCustomBlockTable(QWidget *parent):QTableWidget(parent) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cCustomBlockTable::cCustomBlockTable");
 
     CompositionList =NULL;
+    CurrentSlide    =NULL;
     IsDragOn        =false;
     TextIcon        =QImage(":/img/MediaIcons/48x48/Text.png");
 
@@ -353,7 +406,7 @@ void cCustomBlockTable::dropEvent(QDropEvent *event) {
 void cCustomBlockTable::dragMoveEvent(QDragMoveEvent *event) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cCustomBlockTable::dragMoveEvent");
     int OldDragItemDest=DragItemDest;
-    DragItemDest=(event->pos().y()+verticalOffset())/rowHeight(0);
+    if (rowCount()>0) DragItemDest=(event->pos().y()+verticalOffset())/rowHeight(0); else DragItemDest=0;
     if (DragItemDest>rowCount())    setCursor(Qt::ForbiddenCursor);
         else                        setCursor(Qt::ClosedHandCursor);
     event->acceptProposedAction();
