@@ -25,32 +25,36 @@
 #include <QTextCharFormat>
 #include <QTextList>
 #include <QAbstractTextDocumentLayout>
+#include <QStringListModel>
 
 #define SIZERATIO                       0.5
 
 // Undo actions
-#define UNDOACTION_MODIFTEXT            1
-#define UNDOACTION_BRUSHTYPE            2
-#define UNDOACTION_BRUSHPATTERNBRUSH    3
-#define UNDOACTION_BRUSHORIENTATION     4
-#define UNDOACTION_BRUSHFIRSTCOLOR      5
-#define UNDOACTION_BRUSHFINALCOLOR      6
-#define UNDOACTION_BRUSHINTERMCOLOR     7
-#define UNDOACTION_BRUSHINTERMPOS       8
-#define UNDOACTION_BRUSHLIBBRUSH        9
-#define UNDOACTION_FONTCOLOR            10
-#define UNDOACTION_FONTSHADOWCOLOR      11
-#define UNDOACTION_FONTSTYLE            12
-#define UNDOACTION_FONTSIZE             13
-#define UNDOACTION_FONTEFFECT           14
-#define UNDOACTION_CHARSTYLE            15
-#define UNDOACTION_ALIGNH               16
-#define UNDOACTION_ALIGNV               17
-#define UNDOACTION_INDENT               18
-#define UNDOACTION_LIST                 19
-#define UNDOSTYLE_TEXT                  20
-#define UNDOSTYLE_BACKGROUND            21
-
+enum {
+    UNDOACTION_,
+    UNDOACTION_MODIFTEXT,
+    UNDOACTION_BRUSHTYPE,
+    UNDOACTION_BRUSHPATTERNBRUSH,
+    UNDOACTION_BRUSHORIENTATION,
+    UNDOACTION_BRUSHFIRSTCOLOR,
+    UNDOACTION_BRUSHFINALCOLOR,
+    UNDOACTION_BRUSHINTERMCOLOR,
+    UNDOACTION_BRUSHINTERMPOS,
+    UNDOACTION_BRUSHLIBBRUSH,
+    UNDOACTION_FONTCOLOR,
+    UNDOACTION_FONTSHADOWCOLOR,
+    UNDOACTION_FONTSTYLE,
+    UNDOACTION_FONTSIZE,
+    UNDOACTION_FONTEFFECT,
+    UNDOACTION_CHARSTYLE,
+    UNDOACTION_ALIGNH,
+    UNDOACTION_ALIGNV,
+    UNDOACTION_INDENT,
+    UNDOACTION_LIST,
+    UNDOSTYLE_TEXT,
+    UNDOSTYLE_BACKGROUND,
+    UNDOSTYLE_MARGINS
+};
 
 //====================================================================================================================
 
@@ -115,15 +119,12 @@ void DlgTextEdit::DoInitDialog() {
     CurrentPlainText=ui->TextEdit->toPlainText();
 
     // Init combo box FontEffect
-    ui->fontEffectCB->addItem(QApplication::translate("DlgTextEdit","No effect"));
-    ui->fontEffectCB->addItem(QApplication::translate("DlgTextEdit","Outerline"));
-    ui->fontEffectCB->addItem(QApplication::translate("DlgTextEdit","Shadow upper left"));
-    ui->fontEffectCB->addItem(QApplication::translate("DlgTextEdit","Shadow upper right"));
-    ui->fontEffectCB->addItem(QApplication::translate("DlgTextEdit","Shadow bottom left"));
-    ui->fontEffectCB->addItem(QApplication::translate("DlgTextEdit","Shadow bottom right"));
-    ui->fontEffectCB->view()->setFixedWidth(160+18);
-    ui->fontEffectCB->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
-    MakeTextStyleIcon(ui->fontEffectCB);
+    ui->fontEffectCB->addItem(QIcon(":/img/Text/normal.png"),               QApplication::translate("DlgTextEdit","No effect"));
+    ui->fontEffectCB->addItem(QIcon(":/img/Text/outline.png"),              QApplication::translate("DlgTextEdit","Outerline"));
+    ui->fontEffectCB->addItem(QIcon(":/img/Text/Shadow upper left.png"),    QApplication::translate("DlgTextEdit","Shadow upper left"));
+    ui->fontEffectCB->addItem(QIcon(":/img/Text/Shadow upper right.png"),   QApplication::translate("DlgTextEdit","Shadow upper right"));
+    ui->fontEffectCB->addItem(QIcon(":/img/Text/Shadow bottom left.png"),   QApplication::translate("DlgTextEdit","Shadow bottom left"));
+    ui->fontEffectCB->addItem(QIcon(":/img/Text/Shadow bottom right.png"),  QApplication::translate("DlgTextEdit","Shadow bottom right"));
 
     // Init combo box Background  type
     ui->BrushTypeCombo->addItem(QApplication::translate("DlgTextEdit","No brush"));              ui->BrushTypeCombo->setItemData(ui->BrushTypeCombo->count()-1,QVariant(int(BRUSHTYPE_NOBRUSH)));
@@ -181,6 +182,15 @@ void DlgTextEdit::DoInitDialog() {
     connect(ui->TextStyleBT,SIGNAL(pressed()),this,SLOT(s_TextStyleBT()));
     connect(ui->BackgroundStyleBT,SIGNAL(pressed()),this,SLOT(s_BackgroundStyleBT()));
 
+    // Margins
+    connect(ui->ShapeDefaultBT,SIGNAL(pressed()),this,SLOT(s_ShapeDefault_Changed()));
+    connect(ui->FullShapeBT,SIGNAL(pressed()),this,SLOT(s_FullShape_Changed()));
+    connect(ui->CustomBT,SIGNAL(pressed()),this,SLOT(s_Custom_Changed()));
+    connect(ui->PosXEd,SIGNAL(valueChanged(int)),this,SLOT(s_PosXEd_Changed(int)));
+    connect(ui->PosYEd,SIGNAL(valueChanged(int)),this,SLOT(s_PosYEd_Changed(int)));
+    connect(ui->WidthEd,SIGNAL(valueChanged(int)),this,SLOT(s_WidthEd_Changed(int)));
+    connect(ui->HeightEd,SIGNAL(valueChanged(int)),this,SLOT(s_HeightEd_Changed(int)));
+
     RefreshControls();
 }
 
@@ -287,13 +297,30 @@ void DlgTextEdit::RefreshControls() {
 
     StopMAJSpinbox=true;
 
+    // Margins
+    ui->ShapeDefaultBT->setChecked( CurrentTextItem->TMType==TEXTMARGINS_SHAPEDEFAULT);
+    ui->FullShapeBT->setChecked(    CurrentTextItem->TMType==TEXTMARGINS_FULLSHAPE);
+    ui->CustomBT->setChecked(       CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosSize_X->setEnabled(      CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosXEd->setEnabled(         CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosSize_Y->setEnabled(      CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosYEd->setEnabled(         CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosSize_Width->setEnabled(  CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->WidthEd->setEnabled(        CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosSize_Height->setEnabled( CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->HeightEd->setEnabled(       CurrentTextItem->TMType==TEXTMARGINS_CUSTOM);
+    ui->PosXEd->setValue(     round(CurrentTextItem->TMx*100));
+    ui->PosYEd->setValue(     round(CurrentTextItem->TMy*100));
+    ui->WidthEd->setValue(    round(CurrentTextItem->TMw*100));
+    ui->HeightEd->setValue(   round(CurrentTextItem->TMh*100));
+
     ui->textUp->setChecked(CurrentTextItem->VAlign==0);                 ui->textUp->setDown(CurrentTextItem->VAlign==0);
     ui->textVCenter->setChecked(CurrentTextItem->VAlign==1);            ui->textVCenter->setDown(CurrentTextItem->VAlign==1);
     ui->textBottom->setChecked(CurrentTextItem->VAlign==2);             ui->textBottom->setDown(CurrentTextItem->VAlign==2);
     if (CurrentTextItem->StyleText!=ui->fontEffectCB->currentIndex())   ui->fontEffectCB->setCurrentIndex(CurrentTextItem->StyleText);
     ui->StyleShadowColorCombo->SetCurrentColor(&CurrentTextItem->FontShadowColor);
     ui->StyleShadowColorCombo->setEnabled(CurrentTextItem->StyleText!=0);
-    ui->fontEffectCB->view()->setFixedWidth(250);
+    //ui->fontEffectCB->view()->setFixedWidth(250);
     //ui->TextStyleED->setText(StyleTextCollection->GetStyleName(CurrentTextItem->GetTextStyle()));
 
     // Brush TAB part
@@ -371,36 +398,6 @@ void DlgTextEdit::RefreshControls() {
     emit RefreshDisplay();
 }
 
-void DlgTextEdit::MakeTextStyleIcon(QComboBox *UICB) {
-    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::MakeTextStyleIcon");
-
-    for (int i=0;i<UICB->count();i++) {
-        cCompositionObject Object(COMPOSITIONTYPE_BACKGROUND,0,BaseApplicationConfig);
-        Object.Text="T";
-        Object.x=0.15;
-        Object.y=0.15;
-        Object.w=0.7;
-        Object.h=0.7;
-        Object.HAlign           =1;                 // Center
-        Object.VAlign           =1;                 // Center
-        Object.FontColor        ="#00ff00";
-        Object.FontShadowColor  ="#ff0000";
-        Object.StyleText        =i;
-        Object.FontSize         =200;
-        Object.IsBold           =true;
-        Object.PenSize          =0;
-        Object.BackgroundForm   =1;
-        Object.Opacity=0;
-        QPixmap  Image(32,32);
-        QPainter Painter;
-        Painter.begin(&Image);
-        Painter.fillRect(QRect(0,0,32,32),"#ffffff");
-        Object.DrawCompositionObject(&Painter,1,0,0,32,32,true,0,0,NULL,1,NULL,false,0,false);
-        Painter.end();
-        UICB->setItemIcon(i,QIcon(Image));
-    }
-}
-
 //====================================================================================================================
 // Handler for text controls
 //====================================================================================================================
@@ -412,9 +409,13 @@ void DlgTextEdit::s_SetBold() {
     AppendPartialUndo(UNDOACTION_CHARSTYLE,ui->TextEdit,true);
 
     QTextCursor     Cursor(ui->TextEdit->textCursor());
-    QTextCharFormat TCF;
+    QTextCharFormat TCF,CurrentFormat;
+
+    if (Cursor.hasSelection())  CurrentFormat=Cursor.charFormat();                // Display option for current selection
+        else                    CurrentFormat=ui->TextEdit->currentCharFormat();  // Display current default option
+
+    TCF.setFontWeight(CurrentFormat.fontWeight()==QFont::Normal?QFont::Bold:QFont::Normal);
 
-    TCF.setFontWeight(TCF.fontWeight()==QFont::Normal?QFont::Bold:QFont::Normal);
     if (Cursor.hasSelection())  Cursor.mergeCharFormat(TCF);
         else                    ui->TextEdit->mergeCurrentCharFormat(TCF);
 
@@ -431,9 +432,13 @@ void DlgTextEdit::s_SetItalic() {
     AppendPartialUndo(UNDOACTION_CHARSTYLE,ui->TextEdit,true);
 
     QTextCursor     Cursor(ui->TextEdit->textCursor());
-    QTextCharFormat TCF;
+    QTextCharFormat TCF,CurrentFormat;
+
+    if (Cursor.hasSelection())  CurrentFormat=Cursor.charFormat();                // Display option for current selection
+        else                    CurrentFormat=ui->TextEdit->currentCharFormat();  // Display current default option
+
+    TCF.setFontItalic(!CurrentFormat.fontItalic());
 
-    TCF.setFontItalic(!TCF.fontItalic());
     if (Cursor.hasSelection())  Cursor.mergeCharFormat(TCF);
         else                    ui->TextEdit->mergeCurrentCharFormat(TCF);
 
@@ -450,9 +455,12 @@ void DlgTextEdit::s_SetUnderline() {
     AppendPartialUndo(UNDOACTION_CHARSTYLE,ui->TextEdit,true);
 
     QTextCursor     Cursor(ui->TextEdit->textCursor());
-    QTextCharFormat TCF;
+    QTextCharFormat TCF,CurrentFormat;
 
-    TCF.setFontUnderline(!TCF.fontUnderline());
+    if (Cursor.hasSelection())  CurrentFormat=Cursor.charFormat();                // Display option for current selection
+        else                    CurrentFormat=ui->TextEdit->currentCharFormat();  // Display current default option
+
+    TCF.setFontUnderline(!CurrentFormat.fontUnderline());
     if (Cursor.hasSelection())  Cursor.mergeCharFormat(TCF);
         else                    ui->TextEdit->mergeCurrentCharFormat(TCF);
 
@@ -925,3 +933,60 @@ void DlgTextEdit::s_BackgroundStyleBT() {
     }
     RefreshControls();
 }
+
+//====================================================================================================================
+// Handler for margins part
+//====================================================================================================================
+
+void DlgTextEdit::s_ShapeDefault_Changed() {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_ShapeDefault_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->ShapeDefaultBT,true);
+    CurrentTextItem->ApplyTextMargin(TEXTMARGINS_SHAPEDEFAULT);
+    RefreshControls();
+}
+
+void DlgTextEdit::s_FullShape_Changed() {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_FullShape_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->FullShapeBT,true);
+    CurrentTextItem->ApplyTextMargin(TEXTMARGINS_FULLSHAPE);
+    RefreshControls();
+}
+
+void DlgTextEdit::s_Custom_Changed() {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_Custom_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->CustomBT,true);
+    CurrentTextItem->ApplyTextMargin(TEXTMARGINS_CUSTOM);
+    RefreshControls();
+}
+
+void DlgTextEdit::s_PosXEd_Changed(int) {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_PosXEd_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->CustomBT,false);
+    CurrentTextItem->TMx=double(ui->PosXEd->value())/double(100);
+    if (CurrentTextItem->TMx+CurrentTextItem->TMw>1) CurrentTextItem->TMx=1-CurrentTextItem->TMw;
+    RefreshControls();
+}
+
+void DlgTextEdit::s_PosYEd_Changed(int) {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_PosYEd_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->CustomBT,false);
+    CurrentTextItem->TMy=double(ui->PosYEd->value())/100;
+    if (CurrentTextItem->TMy+CurrentTextItem->TMh>1) CurrentTextItem->TMy=1-CurrentTextItem->TMh;
+    RefreshControls();
+}
+
+void DlgTextEdit::s_WidthEd_Changed(int) {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_WidthEd_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->CustomBT,false);
+    CurrentTextItem->TMw=double(ui->WidthEd->value())/100;
+    if (CurrentTextItem->TMx+CurrentTextItem->TMw>1) CurrentTextItem->TMw=1-CurrentTextItem->TMx;
+    RefreshControls();
+}
+
+void DlgTextEdit::s_HeightEd_Changed(int) {
+    ToLog(LOGMSG_DEBUGTRACE,"IN:DlgTextEdit::s_HeightEd_Changed");
+    AppendPartialUndo(UNDOSTYLE_MARGINS,ui->CustomBT,false);
+    CurrentTextItem->TMh=double(ui->HeightEd->value())/100;
+    if (CurrentTextItem->TMy+CurrentTextItem->TMh>1) CurrentTextItem->TMh=1-CurrentTextItem->TMy;
+    RefreshControls();
+}
