@@ -32,28 +32,6 @@
 #define RULER_VERT_UNSELECTED       0x0080
 #define RULER_DEFAULT               RULER_HORIZ_SCREENBORDER|RULER_HORIZ_TVMARGIN|RULER_HORIZ_SCREENCENTER|RULER_HORIZ_UNSELECTED|RULER_VERT_SCREENBORDER|RULER_VERT_TVMARGIN|RULER_VERT_SCREENCENTER|RULER_VERT_UNSELECTED
 
-/****************************************************************************
-  Other
-****************************************************************************/
-QString SystemProperties="";                                    // System properties log
-QString CurrentAppVersion="";                                   // Application version read from BUILDVERSION.txt
-
-void AddToSystemProperties(QString StringToAdd) {
-    if (SystemProperties.length()>0) SystemProperties=SystemProperties+"\n";
-    SystemProperties=SystemProperties+StringToAdd;
-}
-
-void AddSeparatorToSystemProperties() {
-    AddToSystemProperties("------------------------------------------------------------------------------");
-}
-
-void ExitApplicationWithFatalError(QString StringToAdd) {
-    AddSeparatorToSystemProperties();
-    AddToSystemProperties(StringToAdd);
-    fprintf(stderr,"%s\n",SystemProperties.toLocal8Bit().data());     // Print out SystemProperties
-    exit(1);
-}
-
 //====================================================================================================================
 
 cSaveDlgSlideProperties::cSaveDlgSlideProperties(QString WindowName,bool &RestoreWindow,bool IsMainWindow):cSaveWindowPosition(WindowName,RestoreWindow,IsMainWindow) {
@@ -85,7 +63,7 @@ void cSaveDlgSlideProperties::OverloadedLoadFromXML(QDomElement Element) {
 
 //====================================================================================================================
 
-cApplicationConfig::cApplicationConfig(QMainWindow *TheTopLevelWindow):cBaseApplicationConfig(TheTopLevelWindow,ALLOWEDWEBLANGUAGE,APPLICATION_NAME,APPLICATION_NAME,APPLICATION_VERSION,CONFIGFILEEXT,CONFIGFILE_ROOTNAME) {
+cApplicationConfig::cApplicationConfig(QMainWindow *TheTopLevelWindow):cBaseApplicationConfig(TheTopLevelWindow,ALLOWEDWEBLANGUAGE,APPLICATION_NAME,APPLICATION_NAME,CurrentAppName,CONFIGFILEEXT,CONFIGFILE_ROOTNAME) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cApplicationConfig::cApplicationConfig");
 }
 
@@ -98,10 +76,11 @@ cApplicationConfig::~cApplicationConfig() {
     delete DlgApplicationSettingsWSP;
     delete DlgRenderVideoWSP;
     delete DlgTransitionPropertiesWSP;
+    delete DlgTransitionDurationWSP;
     delete DlgSlidePropertiesWSP;
+    delete DlgSlideDurationWSP;
     delete DlgImageTransformationWSP;
     delete DlgImageCorrectionWSP;
-    delete DlgVideoEditWSP;
     delete DlgTextEditWSP;
     delete DlgManageStyleWSP;
     delete DlgCheckConfigWSP;
@@ -110,6 +89,7 @@ cApplicationConfig::~cApplicationConfig() {
     delete DlgffDPjrPropertiesWSP;
     delete DlgInfoFileWSP;
     delete DlgRulerDef;
+    delete DlgManageFavoriteWSP;
 }
 
 //====================================================================================================================
@@ -118,22 +98,26 @@ void cApplicationConfig::InitValues() {
     ToLog(LOGMSG_DEBUGTRACE,"IN:cApplicationConfig::InitValues");
 
     // Initialise all variables and set them default value
+    WindowDisplayMode           = DISPLAYWINDOWMODE_PLAYER; // Mainwindow display mode
+    PartitionMode               = false;                    // If true, partition mode is on (timeline with multiple row)
+    MemCacheMaxValue            = qlonglong(512*1024*1024);
     AskUserToRemove             = true;                     // If true, user must answer to a confirmation dialog box to remove slide
     SortFile                    = true;                     // if true sort file by (last) number when multiple file insertion
     AppendObject                = false;                    // If true, new object will be append at the end of the diaporama, if false, new object will be insert after current position
-    PartitionMode               = false;                    // If true, partition mode is on
     DisplayUnit                 = 1;                        // Display coordinates unit
     DefaultFraming              = 2;                        // 0=Width, 1=Height, 2=Full
-    TimelineHeight              = 120;                      // Initial height of the timeline
+    TimelineHeight              = TIMELINEMINHEIGH;         // Initial height of the timeline
     PreviewFPS                  = 12.5;                     // Preview FrameRate
     NoShotDuration              = 6000;                     // Default duration for fixed image when is alone (no shot)
     FixedDuration               = 3000;                     // Default duration for fixed image (msec)
-    SpeedWave                   = SPEEDWAVE_LINEAR;         // Default speed wave methode
     ImageGeometry               = GEOMETRY_16_9;            // Project image geometry for image rendering
     SlideRuler                  = RULER_DEFAULT;            // if true, ruler is on in slide properties dialog box
     FramingRuler                = true;                     // if true, ruler is on in framing/correction dialog box
     DefaultTitleFilling         = 0;                        // Default Title filling mode
     DefaultAuthor               = "";                       // Default Author name
+    DefaultTransitionSpeedWave  = SPEEDWAVE_SINQUARTER;     // Default Speed wave for transition
+    DefaultBlockAnimSpeedWave   = SPEEDWAVE_LINEAR;         // Default Speed wave for block animation
+    DefaultImageAnimSpeedWave   = SPEEDWAVE_LINEAR;         // Default Speed wave for image framing and correction animation
 
     DefaultFormat               = 1;                        // Default format = avi
     DefaultNameProjectName      =true;                      // Use project name as default name for rendering
@@ -160,34 +144,32 @@ void cApplicationConfig::InitValues() {
         LastCaptureImage        = WINDOWS_PICTURES;             // Last folder use for captured image
         if (LastRenderVideoPath=="") LastRenderVideoPath=WINDOWS_DOCUMENTS;
         SDLAudioOldMode         = false;                        // If true SDL audio use old mode sample instead byte
+        QSettings Settings("HKEY_CURRENT_USER\\Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders",QSettings::NativeFormat);
+        CurrentPath=Settings.value("Personal").toString();
     #endif
     #ifdef Q_WS_X11
         LastProjectPath         = QDir::home().absolutePath();  // Last folder use for project
         LastRenderVideoPath     = QDir::home().absolutePath();  // Last folder use for render video
         LastCaptureImage        = QDir::home().absolutePath();  // Last folder use for captured image
         SDLAudioOldMode         = true;                         // If true SDL audio use old mode sample instead byte
+        CurrentPath="~";   // User home folder
     #endif
 
-    AddToSystemProperties(QString(OPERATINGSYSTEM_STR)+Plateforme+" - "+QString("%1").arg(getCpuCount())+" Core/CPU");
-    AddToSystemProperties(QString(USERCONFIGFILE_STR)+UserConfigFile);
-    AddToSystemProperties(QString(GLOBALCONFIGFILE_STR)+GlobalConfigFile);
-
     // Init collections
     StyleTextCollection.CollectionName          =QString(STYLENAME_TEXTSTYLE);
     StyleTextBackgroundCollection.CollectionName=QString(STYLENAME_BACKGROUNDSTYLE);
-    StyleCoordinateCollection.CollectionName    =QString(STYLENAME_COORDINATESTYLE);
     StyleBlockShapeCollection.CollectionName    =QString(STYLENAME_BLOCKSHAPESTYLE);
-    StyleImageFramingCollection.CollectionName  =QString(STYLENAME_FRAMINGSTYLE);
 
     DlgBackgroundPropertiesWSP  =new cSaveWindowPosition("DlgBackgroundProperties",RestoreWindow,false);    // Dialog box "Background properties" - Window size and position
     DlgMusicPropertiesWSP       =new cSaveWindowPosition("DlgMusicProperties",RestoreWindow,false);         // Dialog box "Music properties" - Window size and position
     DlgApplicationSettingsWSP   =new cSaveWindowPosition("DlgApplicationSettings",RestoreWindow,false);     // Dialog box "Application settings" - Window size and position
     DlgRenderVideoWSP           =new cSaveWindowPosition("DlgRenderVideoWSP",RestoreWindow,false);          // Dialog box "Render Video" - Window size and position
     DlgTransitionPropertiesWSP  =new cSaveWindowPosition("DlgTransitionPropertiesWSP",RestoreWindow,false); // Dialog box "Transition properties" - Window size and position
+    DlgTransitionDurationWSP    =new cSaveWindowPosition("DlgTransitionDurationWSP",RestoreWindow,false);   // Dialog box "Transition duration" - Window size and position
     DlgSlidePropertiesWSP       =new cSaveDlgSlideProperties("DlgSlidePropertiesWSP",RestoreWindow,false);  // Dialog box "Slide properties" - Window size and position
+    DlgSlideDurationWSP         =new cSaveDlgSlideProperties("DlgSlideDurationWSP",RestoreWindow,false);    // Dialog box "Slide duration" - Window size and position
     DlgImageTransformationWSP   =new cSaveWindowPosition("DlgImageTransformationWSP",RestoreWindow,false);  // Dialog box "Image transformation" - Window size and position
     DlgImageCorrectionWSP       =new cSaveWindowPosition("DlgImageCorrectionWSP",RestoreWindow,false);      // Dialog box "Image correction" - Window size and position
-    DlgVideoEditWSP             =new cSaveWindowPosition("DlgVideoEditWSP",RestoreWindow,false);            // Dialog box "Edit video" - Window size and position
     DlgTextEditWSP              =new cSaveWindowPosition("DlgTextEditWSP",RestoreWindow,false);             // Dialog box "Text editor" - Window size and position
     DlgManageStyleWSP           =new cSaveWindowPosition("DlgManageStyleWSP",RestoreWindow,false);          // Dialog box "Manage style" - Window size and position
     DlgCheckConfigWSP           =new cSaveWindowPosition("DlgCheckConfigWSP",RestoreWindow,false);          // Dialog box "Check configuration" - Window size and position
@@ -196,26 +178,36 @@ void cApplicationConfig::InitValues() {
     DlgffDPjrPropertiesWSP      =new cSaveWindowPosition("DlgffDPjrPropertiesWSP",RestoreWindow,false);     // Dialog box "Project properties" - Window size and position
     DlgInfoFileWSP              =new cSaveWindowPosition("DlgInfoFileWSP",RestoreWindow,false);             // Dialog box "File Information" - Window size and position
     DlgRulerDef                 =new cSaveWindowPosition("DlgRulerDef",RestoreWindow,false);                // Dialog box "Ruler properties" - Window size and position
+    DlgManageFavoriteWSP        =new cSaveWindowPosition("DlgManageFavoriteWSP",RestoreWindow,false);       // Dialog box "Manage favorite" - Window size and position
 
     // Default new text block options
     DefaultBlock_Text_TextST    ="###GLOBALSTYLE###:0";
     DefaultBlock_Text_BackGST   ="###GLOBALSTYLE###:0";
     DefaultBlock_Text_ShapeST   ="###GLOBALSTYLE###:0";
-    for (int i=0;i<3;i++) DefaultBlock_Text_CoordST[i]="###GLOBALSTYLE###:0";
+    DefaultBlock_AutoSizePos    =AUTOCOMPOSIZE_HALFSCREEN;
+    DefaultBlock_AutoLocking    =AUTOFRAMING_CUSTOMUNLOCK;
 
     // Default new image block option (when slide creation)
     DefaultBlockSL_IMG_TextST   ="###GLOBALSTYLE###:0";
     DefaultBlockSL_IMG_ShapeST  ="###GLOBALSTYLE###:0";
-    for (int i=0;i<9;i++) for (int j=0;j<3;j++) DefaultBlockSL_IMG_CoordST[i][j]="###GLOBALSTYLE###:0";
+    DefaultBlockSL[IMAGETYPE_UNKNOWN         ].AutoCompo=DefaultBlock_AutoSizePos;      DefaultBlockSL[IMAGETYPE_UNKNOWN         ].AutoFraming=DefaultBlock_AutoLocking;
+    DefaultBlockSL[IMAGETYPE_PHOTOLANDSCAPE  ].AutoCompo=AUTOCOMPOSIZE_FULLSCREEN;      DefaultBlockSL[IMAGETYPE_PHOTOLANDSCAPE  ].AutoFraming=AUTOFRAMING_WIDTHMIDLEMAX;
+    DefaultBlockSL[IMAGETYPE_PHOTOPORTRAIT   ].AutoCompo=AUTOCOMPOSIZE_FULLSCREEN;      DefaultBlockSL[IMAGETYPE_PHOTOPORTRAIT   ].AutoFraming=AUTOFRAMING_HEIGHTMIDLEMAX;
+    DefaultBlockSL[IMAGETYPE_CLIPARTLANDSCAPE].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockSL[IMAGETYPE_CLIPARTLANDSCAPE].AutoFraming=AUTOFRAMING_FULLMAX;
+    DefaultBlockSL[IMAGETYPE_CLIPARTPORTRAIT ].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockSL[IMAGETYPE_CLIPARTPORTRAIT ].AutoFraming=AUTOFRAMING_FULLMAX;
+    DefaultBlockSL[IMAGETYPE_VIDEOLANDSCAPE  ].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockSL[IMAGETYPE_VIDEOLANDSCAPE  ].AutoFraming=AUTOFRAMING_FULLMAX;
+    DefaultBlockSL[IMAGETYPE_VIDEOPORTRAIT   ].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockSL[IMAGETYPE_VIDEOPORTRAIT   ].AutoFraming=AUTOFRAMING_FULLMAX;
 
     // Default new image block option (when block add in slide dialog)
     DefaultBlockBA_IMG_TextST   ="###GLOBALSTYLE###:0";
     DefaultBlockBA_IMG_ShapeST  ="###GLOBALSTYLE###:0";
-    for (int i=0;i<9;i++) for (int j=0;j<3;j++) DefaultBlockBA_IMG_CoordST[i][j]="###GLOBALSTYLE###:0";
-    for (int i=0;i<3;i++) {
-        DefaultBlockSL_CLIPARTLOCK[i]=0;
-        DefaultBlockBA_CLIPARTLOCK[i]=0;
-    }
+    DefaultBlockBA[IMAGETYPE_UNKNOWN         ].AutoCompo=DefaultBlock_AutoSizePos;      DefaultBlockBA[IMAGETYPE_UNKNOWN         ].AutoFraming=DefaultBlock_AutoLocking;
+    DefaultBlockBA[IMAGETYPE_PHOTOLANDSCAPE  ].AutoCompo=AUTOCOMPOSIZE_HALFSCREEN;      DefaultBlockBA[IMAGETYPE_PHOTOLANDSCAPE  ].AutoFraming=AUTOFRAMING_WIDTHMIDLEMAX;
+    DefaultBlockBA[IMAGETYPE_PHOTOPORTRAIT   ].AutoCompo=AUTOCOMPOSIZE_HALFSCREEN;      DefaultBlockBA[IMAGETYPE_PHOTOPORTRAIT   ].AutoFraming=AUTOFRAMING_HEIGHTMIDLEMAX;
+    DefaultBlockBA[IMAGETYPE_CLIPARTLANDSCAPE].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockBA[IMAGETYPE_CLIPARTLANDSCAPE].AutoFraming=AUTOFRAMING_FULLMAX;
+    DefaultBlockBA[IMAGETYPE_CLIPARTPORTRAIT ].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockBA[IMAGETYPE_CLIPARTPORTRAIT ].AutoFraming=AUTOFRAMING_FULLMAX;
+    DefaultBlockBA[IMAGETYPE_VIDEOLANDSCAPE  ].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockBA[IMAGETYPE_VIDEOLANDSCAPE  ].AutoFraming=AUTOFRAMING_FULLMAX;
+    DefaultBlockBA[IMAGETYPE_VIDEOPORTRAIT   ].AutoCompo=AUTOCOMPOSIZE_REALSIZE;        DefaultBlockBA[IMAGETYPE_VIDEOPORTRAIT   ].AutoFraming=AUTOFRAMING_FULLMAX;
 }
 
 //====================================================================================================================
@@ -254,6 +246,7 @@ void cApplicationConfig::SaveValueToXML(QDomElement &domDocument) {
         Element.setAttribute("LastProjectPath",         LastProjectPath);
         Element.setAttribute("LastRenderVideoPath",     LastRenderVideoPath);
         Element.setAttribute("LastCaptureImage",        LastCaptureImage);
+        Element.setAttribute("CurrentBrowserPath",      CurrentPath);
     }
 
     Element=Document.createElement("EditorOptions");
@@ -261,8 +254,10 @@ void cApplicationConfig::SaveValueToXML(QDomElement &domDocument) {
     Element.setAttribute("AppendObject",                AppendObject?"1":"0");
     Element.setAttribute("DisplayUnit",                 DisplayUnit);
     Element.setAttribute("PartitionMode",               PartitionMode?"1":"0");
+    Element.setAttribute("WindowDisplayMode",           WindowDisplayMode);
+    Element.setAttribute("BrowserWidgetSplitter",       BrowserWidgetSplitter);
     Element.setAttribute("SortFile",                    SortFile?"1":"0");
-    Element.setAttribute("TimelineHeight",              TimelineHeight);
+    Element.setAttribute("NewTimelineHeight",           TimelineHeight);
     Element.setAttribute("DefaultFraming",              DefaultFraming);
     Element.setAttribute("PreviewFPS",                  (QString("%1").arg(PreviewFPS,0,'f')));
     Element.setAttribute("RandomTransition",            RandomTransition?"1":"0");
@@ -274,43 +269,49 @@ void cApplicationConfig::SaveValueToXML(QDomElement &domDocument) {
     Element.setAttribute("FramingRuler",                FramingRuler?"1":"0");
     domDocument.appendChild(Element);
 
+    Element=Document.createElement("BrowserFavorites");
+    Element.setAttribute("FavoritesNumber",             BrowserFavorites.count());
+    for (int i=0;i<BrowserFavorites.count();i++) Element.setAttribute(QString("BrowserFavorites_%1").arg(i),BrowserFavorites[i]);
+    domDocument.appendChild(Element);
+
     Element=Document.createElement("ProjectDefault");
     Element.setAttribute("ImageGeometry",               ImageGeometry);
     Element.setAttribute("NoShotDuration",              NoShotDuration);
     Element.setAttribute("FixedDuration",               FixedDuration);
-    Element.setAttribute("SpeedWave",                   SpeedWave);
     Element.setAttribute("DefaultAuthor",               DefaultAuthor);
     Element.setAttribute("DefaultTitleFilling",         DefaultTitleFilling);
+    Element.setAttribute("DefaultTransitionSpeedWave",  DefaultTransitionSpeedWave);
+    Element.setAttribute("DefaultBlockAnimSpeedWave",   DefaultBlockAnimSpeedWave);
+    Element.setAttribute("DefaultImageAnimSpeedWave",   DefaultImageAnimSpeedWave);
 
     SubElement=Document.createElement("DefaultBlock_Text");
-    SubElement.setAttribute("TextST",    DefaultBlock_Text_TextST);
-    SubElement.setAttribute("BackGST",   DefaultBlock_Text_BackGST);
-    SubElement.setAttribute("Coord0ST",  DefaultBlock_Text_CoordST[0]);
-    SubElement.setAttribute("Coord1ST",  DefaultBlock_Text_CoordST[1]);
-    SubElement.setAttribute("Coord2ST",  DefaultBlock_Text_CoordST[2]);
-    SubElement.setAttribute("ShapeST",   DefaultBlock_Text_ShapeST);
+    SubElement.setAttribute("TextST",                   DefaultBlock_Text_TextST);
+    SubElement.setAttribute("BackGST",                  DefaultBlock_Text_BackGST);
+    SubElement.setAttribute("ShapeST",                  DefaultBlock_Text_ShapeST);
+    SubElement.setAttribute("AutoSizePos",              DefaultBlock_AutoSizePos);
+    SubElement.setAttribute("AutoLocking",              DefaultBlock_AutoLocking);
     Element.appendChild(SubElement);
 
     SubElement=Document.createElement("DefaultBlockSL_IMG");
-    SubElement.setAttribute("TextST",    DefaultBlockSL_IMG_TextST);
-    SubElement.setAttribute("ShapeST",   DefaultBlockSL_IMG_ShapeST);
-    for (int i=0;i<9;i++) {
+    SubElement.setAttribute("TextST",                   DefaultBlockSL_IMG_TextST);
+    SubElement.setAttribute("ShapeST",                  DefaultBlockSL_IMG_ShapeST);
+    for (int i=1;i<NBR_IMAGETYPE;i++) {
         SubSubElement=Document.createElement(QString("IMG_GEO_%1").arg(i));
-        for (int j=0;j<3;j++) SubSubElement.setAttribute(QString("CoordST_%1").arg(j),DefaultBlockSL_IMG_CoordST[i][j]);
+        SubSubElement.setAttribute("AutoCompo",         DefaultBlockSL[i].AutoCompo);
+        SubSubElement.setAttribute("AutoFraming",       DefaultBlockSL[i].AutoFraming);
         SubElement.appendChild(SubSubElement);
-        for (int j=0;j<3;j++) SubElement.setAttribute(QString("LockLS_%1").arg(j),DefaultBlockSL_CLIPARTLOCK[j]);
     }
     Element.appendChild(SubElement);
 
     SubElement=Document.createElement("DefaultBlockBA_IMG");
-    SubElement.setAttribute("TextST",    DefaultBlockBA_IMG_TextST);
-    SubElement.setAttribute("ShapeST",   DefaultBlockBA_IMG_ShapeST);
-    for (int i=0;i<9;i++) {
+    SubElement.setAttribute("TextST",                   DefaultBlockBA_IMG_TextST);
+    SubElement.setAttribute("ShapeST",                  DefaultBlockBA_IMG_ShapeST);
+    for (int i=1;i<NBR_IMAGETYPE;i++) {
         SubSubElement=Document.createElement(QString("IMG_GEO_%1").arg(i));
-        for (int j=0;j<3;j++) SubSubElement.setAttribute(QString("CoordST_%1").arg(j),DefaultBlockBA_IMG_CoordST[i][j]);
+        SubSubElement.setAttribute("AutoCompo",         DefaultBlockBA[i].AutoCompo);
+        SubSubElement.setAttribute("AutoFraming",       DefaultBlockBA[i].AutoFraming);
         SubElement.appendChild(SubSubElement);
     }
-    for (int j=0;j<3;j++) SubElement.setAttribute(QString("LockBA_%1").arg(j),DefaultBlockBA_CLIPARTLOCK[j]);
     Element.appendChild(SubElement);
     domDocument.appendChild(Element);
 
@@ -344,9 +345,7 @@ void cApplicationConfig::SaveValueToXML(QDomElement &domDocument) {
     // Save other collections
     StyleTextCollection.SaveToXML(domDocument);
     StyleTextBackgroundCollection.SaveToXML(domDocument);
-    StyleCoordinateCollection.SaveToXML(domDocument);
     StyleBlockShapeCollection.SaveToXML(domDocument);
-    StyleImageFramingCollection.SaveToXML(domDocument);
 
     // Save windows size and position
     DlgBackgroundPropertiesWSP->SaveToXML(domDocument);
@@ -354,10 +353,11 @@ void cApplicationConfig::SaveValueToXML(QDomElement &domDocument) {
     DlgApplicationSettingsWSP->SaveToXML(domDocument);
     DlgRenderVideoWSP->SaveToXML(domDocument);
     DlgTransitionPropertiesWSP->SaveToXML(domDocument);
+    DlgTransitionDurationWSP->SaveToXML(domDocument);
     DlgSlidePropertiesWSP->SaveToXML(domDocument);
+    DlgSlideDurationWSP->SaveToXML(domDocument);
     DlgImageTransformationWSP->SaveToXML(domDocument);
     DlgImageCorrectionWSP->SaveToXML(domDocument);
-    DlgVideoEditWSP->SaveToXML(domDocument);
     DlgTextEditWSP->SaveToXML(domDocument);
     DlgManageStyleWSP->SaveToXML(domDocument);
     DlgCheckConfigWSP->SaveToXML(domDocument);
@@ -366,6 +366,7 @@ void cApplicationConfig::SaveValueToXML(QDomElement &domDocument) {
     DlgffDPjrPropertiesWSP->SaveToXML(domDocument);
     DlgInfoFileWSP->SaveToXML(domDocument);
     DlgRulerDef->SaveToXML(domDocument);
+    DlgManageFavoriteWSP->SaveToXML(domDocument);
 }
 
 //====================================================================================================================
@@ -379,6 +380,7 @@ bool cApplicationConfig::LoadValueFromXML(QDomElement domDocument,LoadConfigFile
         if (Element.hasAttribute("LastProjectPath"))            LastProjectPath             =Element.attribute("LastProjectPath");
         if (Element.hasAttribute("LastRenderVideoPath"))        LastRenderVideoPath         =Element.attribute("LastRenderVideoPath");
         if (Element.hasAttribute("LastCaptureImage"))           LastCaptureImage            =Element.attribute("LastCaptureImage");
+        if (Element.hasAttribute("CurrentBrowserPath"))         CurrentPath                 =Element.attribute("CurrentBrowserPath");
     }
 
     if ((domDocument.elementsByTagName("EditorOptions").length()>0)&&(domDocument.elementsByTagName("EditorOptions").item(0).isElement()==true)) {
@@ -390,9 +392,13 @@ bool cApplicationConfig::LoadValueFromXML(QDomElement domDocument,LoadConfigFile
         if (Element.hasAttribute("SDLAudioOldMode"))            SDLAudioOldMode             =Element.attribute("SDLAudioOldMode")=="1";
         if (Element.hasAttribute("AppendObject"))               AppendObject                =Element.attribute("AppendObject")=="1";
         if (Element.hasAttribute("PartitionMode"))              PartitionMode               =Element.attribute("PartitionMode")=="1";
+        if (Element.hasAttribute("WindowDisplayMode"))          WindowDisplayMode           =Element.attribute("WindowDisplayMode").toInt();
+        if (Element.hasAttribute("BrowserWidgetSplitter"))      BrowserWidgetSplitter       =Element.attribute("BrowserWidgetSplitter");
         if (Element.hasAttribute("DisplayUnit"))                DisplayUnit                 =Element.attribute("DisplayUnit").toInt();
         if (Element.hasAttribute("SortFile"))                   SortFile                    =Element.attribute("SortFile")=="1";
-        if (Element.hasAttribute("TimelineHeight"))             TimelineHeight              =Element.attribute("TimelineHeight").toInt();
+        if (Element.hasAttribute("NewTimelineHeight"))          TimelineHeight              =Element.attribute("NewTimelineHeight").toInt();
+        if (TimelineHeight<TIMELINEMINHEIGH) TimelineHeight=TIMELINEMINHEIGH;
+        if (TimelineHeight>TIMELINEMAXHEIGH) TimelineHeight=TIMELINEMAXHEIGH;
         if (Element.hasAttribute("DefaultFraming"))             DefaultFraming              =Element.attribute("DefaultFraming").toInt();
         if (Element.hasAttribute("PreviewFPS"))                 PreviewFPS                  =Element.attribute("PreviewFPS").toDouble();
         if (Element.hasAttribute("RandomTransition"))           RandomTransition            =Element.attribute("RandomTransition")=="1";
@@ -405,44 +411,60 @@ bool cApplicationConfig::LoadValueFromXML(QDomElement domDocument,LoadConfigFile
         if (Element.hasAttribute("FramingRuler"))               FramingRuler                =Element.attribute("FramingRuler")!="0";
     }
 
+    if ((domDocument.elementsByTagName("BrowserFavorites").length()>0)&&(domDocument.elementsByTagName("BrowserFavorites").item(0).isElement()==true)) {
+        QDomElement Element=domDocument.elementsByTagName("BrowserFavorites").item(0).toElement();
+        int FavToLoad=0;
+        if (Element.hasAttribute("FavoritesNumber")) FavToLoad=Element.attribute("FavoritesNumber").toInt();
+        BrowserFavorites.clear();
+        for (int i=0;i<FavToLoad;i++) if (Element.hasAttribute(QString("BrowserFavorites_%1").arg(i))) BrowserFavorites.append(Element.attribute(QString("BrowserFavorites_%1").arg(i)));
+    }
+
     if ((domDocument.elementsByTagName("ProjectDefault").length()>0)&&(domDocument.elementsByTagName("ProjectDefault").item(0).isElement()==true)) {
         QDomElement  Element=domDocument.elementsByTagName("ProjectDefault").item(0).toElement();
         if (Element.hasAttribute("ImageGeometry"))              ImageGeometry               =Element.attribute("ImageGeometry").toInt();
         if (Element.hasAttribute("NoShotDuration"))             NoShotDuration              =Element.attribute("NoShotDuration").toInt();
         if (Element.hasAttribute("FixedDuration"))              FixedDuration               =Element.attribute("FixedDuration").toInt();
-        if (Element.hasAttribute("SpeedWave"))                  SpeedWave                   =Element.attribute("SpeedWave").toInt();
         if (Element.hasAttribute("DefaultTitleFilling"))        DefaultTitleFilling         =Element.attribute("DefaultTitleFilling").toInt();
         if (Element.hasAttribute("DefaultAuthor"))              DefaultAuthor               =Element.attribute("DefaultAuthor");
+        if (Element.hasAttribute("DefaultTransitionSpeedWave")) DefaultTransitionSpeedWave  =Element.attribute("DefaultTransitionSpeedWave").toInt();
+        if (Element.hasAttribute("DefaultBlockAnimSpeedWave"))  DefaultBlockAnimSpeedWave   =Element.attribute("DefaultBlockAnimSpeedWave").toInt();
+        if (Element.hasAttribute("DefaultImageAnimSpeedWave"))  DefaultImageAnimSpeedWave   =Element.attribute("DefaultImageAnimSpeedWave").toInt();
+
+        // Compatibility with version prior to 1.5
+        if (Element.hasAttribute("SpeedWave")) {
+            DefaultTransitionSpeedWave=Element.attribute("SpeedWave").toInt();
+            DefaultBlockAnimSpeedWave =Element.attribute("SpeedWave").toInt();
+            DefaultImageAnimSpeedWave =Element.attribute("SpeedWave").toInt();
+        }
 
         if ((Element.elementsByTagName("DefaultBlock_Text").length()>0)&&(Element.elementsByTagName("DefaultBlock_Text").item(0).isElement()==true)) {
             QDomElement SubElement=Element.elementsByTagName("DefaultBlock_Text").item(0).toElement();
-            if (SubElement.hasAttribute("TextST"))   DefaultBlock_Text_TextST    =SubElement.attribute("TextST");
-            if (SubElement.hasAttribute("BackGST"))  DefaultBlock_Text_BackGST   =SubElement.attribute("BackGST");
-            if (SubElement.hasAttribute("Coord0ST")) DefaultBlock_Text_CoordST[0]=SubElement.attribute("Coord0ST");
-            if (SubElement.hasAttribute("Coord1ST")) DefaultBlock_Text_CoordST[1]=SubElement.attribute("Coord1ST");
-            if (SubElement.hasAttribute("Coord2ST")) DefaultBlock_Text_CoordST[2]=SubElement.attribute("Coord2ST");
-            if (SubElement.hasAttribute("ShapeST"))  DefaultBlock_Text_ShapeST   =SubElement.attribute("ShapeST");
+            if (SubElement.hasAttribute("TextST"))              DefaultBlock_Text_TextST    =SubElement.attribute("TextST");
+            if (SubElement.hasAttribute("BackGST"))             DefaultBlock_Text_BackGST   =SubElement.attribute("BackGST");
+            if (SubElement.hasAttribute("ShapeST"))             DefaultBlock_Text_ShapeST   =SubElement.attribute("ShapeST");
+            if (SubElement.hasAttribute("AutoSizePos"))         DefaultBlock_AutoSizePos    =SubElement.attribute("AutoSizePos").toInt();
+            if (SubElement.hasAttribute("AutoLocking"))         DefaultBlock_AutoLocking    =SubElement.attribute("AutoLocking").toInt();
         }
         if ((Element.elementsByTagName("DefaultBlockSL_IMG").length()>0)&&(Element.elementsByTagName("DefaultBlockSL_IMG").item(0).isElement()==true)) {
             QDomElement SubElement=Element.elementsByTagName("DefaultBlockSL_IMG").item(0).toElement();
             if (SubElement.hasAttribute("TextST"))   DefaultBlockSL_IMG_TextST    =SubElement.attribute("TextST");
             if (SubElement.hasAttribute("ShapeST"))  DefaultBlockSL_IMG_ShapeST   =SubElement.attribute("ShapeST");
-            for (int i=0;i<9;i++) if ((SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).length()>0)&&(SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).item(0).isElement()==true)) {
+            for (int i=1;i<NBR_IMAGETYPE;i++) if ((SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).length()>0)&&(SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).item(0).isElement()==true)) {
                 QDomElement SubSubElement=SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).item(0).toElement();
-                for (int j=0;j<3;j++) if (SubSubElement.hasAttribute(QString("CoordST_%1").arg(j))) DefaultBlockSL_IMG_CoordST[i][j]=SubSubElement.attribute(QString("CoordST_%1").arg(j));
+                if (SubSubElement.hasAttribute("AutoCompo"))   DefaultBlockSL[i].AutoCompo  =SubSubElement.attribute("AutoCompo").toInt();
+                if (SubSubElement.hasAttribute("AutoFraming")) DefaultBlockSL[i].AutoFraming=SubSubElement.attribute("AutoFraming").toInt();
             }
-            for (int j=0;j<3;j++) if (SubElement.hasAttribute(QString("LockLS_%1").arg(j))) DefaultBlockSL_CLIPARTLOCK[j]=SubElement.attribute(QString("LockLS_%1").arg(j)).toInt();
         }
 
         if ((Element.elementsByTagName("DefaultBlockBA_IMG").length()>0)&&(Element.elementsByTagName("DefaultBlockBA_IMG").item(0).isElement()==true)) {
             QDomElement SubElement=Element.elementsByTagName("DefaultBlockBA_IMG").item(0).toElement();
             if (SubElement.hasAttribute("TextST"))   DefaultBlockBA_IMG_TextST    =SubElement.attribute("TextST");
             if (SubElement.hasAttribute("ShapeST"))  DefaultBlockBA_IMG_ShapeST   =SubElement.attribute("ShapeST");
-            for (int i=0;i<9;i++) if ((SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).length()>0)&&(SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).item(0).isElement()==true)) {
+            for (int i=1;i<NBR_IMAGETYPE;i++) if ((SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).length()>0)&&(SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).item(0).isElement()==true)) {
                 QDomElement SubSubElement=SubElement.elementsByTagName(QString("IMG_GEO_%1").arg(i)).item(0).toElement();
-                for (int j=0;j<3;j++) if (SubSubElement.hasAttribute(QString("CoordST_%1").arg(j))) DefaultBlockBA_IMG_CoordST[i][j]=SubSubElement.attribute(QString("CoordST_%1").arg(j));
+                if (SubSubElement.hasAttribute("AutoCompo"))   DefaultBlockBA[i].AutoCompo  =SubSubElement.attribute("AutoCompo").toInt();
+                if (SubSubElement.hasAttribute("AutoFraming")) DefaultBlockBA[i].AutoFraming=SubSubElement.attribute("AutoFraming").toInt();
             }
-            for (int j=0;j<3;j++) if (SubElement.hasAttribute(QString("LockBA_%1").arg(j))) DefaultBlockBA_CLIPARTLOCK[j]=SubElement.attribute(QString("LockBA_%1").arg(j)).toInt();
         }
     }
     if ((domDocument.elementsByTagName("RenderDefault").length()>0)&&(domDocument.elementsByTagName("RenderDefault").item(0).isElement()==true)) {
@@ -485,9 +507,7 @@ bool cApplicationConfig::LoadValueFromXML(QDomElement domDocument,LoadConfigFile
     // Load other collections
     StyleTextCollection.LoadFromXML(domDocument,TypeConfigFile);
     StyleTextBackgroundCollection.LoadFromXML(domDocument,TypeConfigFile);
-    StyleCoordinateCollection.LoadFromXML(domDocument,TypeConfigFile);
     StyleBlockShapeCollection.LoadFromXML(domDocument,TypeConfigFile);
-    StyleImageFramingCollection.LoadFromXML(domDocument,TypeConfigFile);
 
     // Load windows size and position
     DlgBackgroundPropertiesWSP->LoadFromXML(domDocument);
@@ -495,10 +515,11 @@ bool cApplicationConfig::LoadValueFromXML(QDomElement domDocument,LoadConfigFile
     DlgApplicationSettingsWSP->LoadFromXML(domDocument);
     DlgRenderVideoWSP->LoadFromXML(domDocument);
     DlgTransitionPropertiesWSP->LoadFromXML(domDocument);
+    DlgTransitionDurationWSP->LoadFromXML(domDocument);
     DlgSlidePropertiesWSP->LoadFromXML(domDocument);
+    DlgSlideDurationWSP->LoadFromXML(domDocument);
     DlgImageTransformationWSP->LoadFromXML(domDocument);
     DlgImageCorrectionWSP->LoadFromXML(domDocument);
-    DlgVideoEditWSP->LoadFromXML(domDocument);
     DlgTextEditWSP->LoadFromXML(domDocument);
     DlgManageStyleWSP->LoadFromXML(domDocument);
     DlgCheckConfigWSP->LoadFromXML(domDocument);
@@ -507,6 +528,7 @@ bool cApplicationConfig::LoadValueFromXML(QDomElement domDocument,LoadConfigFile
     DlgffDPjrPropertiesWSP->LoadFromXML(domDocument);
     DlgInfoFileWSP->LoadFromXML(domDocument);
     DlgRulerDef->LoadFromXML(domDocument);
+    DlgManageFavoriteWSP->LoadFromXML(domDocument);
 
     return true;
 }
