@@ -23,40 +23,17 @@
 
 // Basic inclusions (common to all files)
 #include "../engine/_GlobalDefines.h"
+#include "../engine/_Transition.h"
 
 // Include some additional standard class
 #include "../engine/cBaseMediaFile.h"
+#include "../engine/cBrushDefinition.h"
 
 // Specific inclusions
 class cDiaporama;
 class cDiaporamaObject;
 
 #include "_ApplicationDefinitions.h"
-#include "_ImagesDefinitions.h"
-
-// Transition familly definition
-#define TRANSITIONFAMILLY_BASE              0
-#define TRANSITIONFAMILLY_ZOOMINOUT         1
-#define TRANSITIONFAMILLY_SLIDE             2
-#define TRANSITIONFAMILLY_PUSH              3
-#define TRANSITIONFAMILLY_LUMA_BAR          4
-#define TRANSITIONFAMILLY_LUMA_BOX          5
-#define TRANSITIONFAMILLY_LUMA_CENTER       6
-#define TRANSITIONFAMILLY_LUMA_CHECKER      7
-#define TRANSITIONFAMILLY_LUMA_CLOCK        8
-#define TRANSITIONFAMILLY_LUMA_SNAKE        9
-#define TRANSITIONFAMILLY_DEFORM            10
-
-// No luma transition : number of sub type
-#define TRANSITIONMAXSUBTYPE_BASE           4
-#define TRANSITIONMAXSUBTYPE_ZOOMINOUT      18
-#define TRANSITIONMAXSUBTYPE_SLIDE          16
-#define TRANSITIONMAXSUBTYPE_PUSH           16
-#define TRANSITIONMAXSUBTYPE_DEFORM         4
-
-// Speed wave forme definition
-#define SPEEDWAVE_LINEAR                    0
-#define SPEEDWAVE_SINQUARTER                1
 
 // Object type definition
 #define DIAPORAMAOBJECTTYPE_EMPTY           0
@@ -83,9 +60,18 @@ class cDiaporamaObject;
 #define BLOCKANIMVALUE_BLINK_FAST           4
 #define BLOCKANIMVALUE_BLINK_VERYFAST       5
 
+//============================================
+// Text margins
+//============================================
+
+#define TEXTMARGINS_FULLSHAPE               0
+#define TEXTMARGINS_SHAPEDEFAULT            1
+#define TEXTMARGINS_CUSTOM                  2
+
 //============================================
 // Default values
 //============================================
+
 #define DEFAULT_FONT_FAMILLY                "Arial"
 #define DEFAULT_FONT_SIZE                   12
 #define DEFAULT_FONT_COLOR                  "#ffffaa"
@@ -106,12 +92,6 @@ class cDiaporamaObject;
 #define DEFAULT_SHAPE_INTERNALBORDERCOLOR2  "#c0c0c0"
 #define DEFAULT_SHAPE_BRUSHCOLORD           "#808080"
 
-//============================================
-// Global static
-//============================================
-
-extern  QBrush  Transparent;    // Transparent brush
-
 //*********************************************************************************************************************************************
 // Base object for composition definition
 //*********************************************************************************************************************************************
@@ -131,6 +111,7 @@ public:
     double              RotateYAxis;            // Rotation from Y axis
 
     // Block Annimation
+    int                 BlockSpeedWave;         // Speed wave for block animation
     int                 BlockAnimType;          // Type of block animation (#define BLOCKANIMTYPE_)
     int                 TurnZAxis;              // BLOCKANIMTYPE_MULTIPLETURN : Number of turn from Z axis
     int                 TurnXAxis;              // BLOCKANIMTYPE_MULTIPLETURN : Number of turn from X axis
@@ -152,6 +133,8 @@ public:
     int                 TxtZoomLevel;           // Zoom Level for text
     int                 TxtScrollX;             // Scrolling X for text
     int                 TxtScrollY;             // Scrolling Y for text
+    int                 TMType;                 // Text margins type (0=full shape, 1=shape default, 2=custom)
+    double              TMx,TMy,TMw,TMh;        // Text margins
 
     // Attribut of the shap part (Global values)
     int                 BackgroundForm;         // Type of the form : 0=None, 1=Rectangle, 2=RoundRect, 3=Buble, 4=Ellipse, 5=Triangle UP (Polygon)
@@ -170,19 +153,24 @@ public:
     ~cCompositionObject();
 
     void        CopyFromCompositionObject(cCompositionObject *CompositionObjectToCopy);
-    void        DrawCompositionObject(QPainter *Painter,double  ADJUST_RATIO,int AddX,int AddY,int width,int height,bool PreviewMode,qlonglong Position,qlonglong StartPosToAdd,
-                                      cSoundBlockList *SoundTrackMontage,double PctDone,cCompositionObject *PreviousCompositionObject,bool UseBrushCache,qlonglong ShotDuration,bool EnableAnimation,
-                                      bool Transfo=false,double NewX=0,double NewY=0,double NewW=0,double NewH=0);
+    void        DrawCompositionObject(QPainter *Painter,double  ADJUST_RATIO,double width,double height,bool PreviewMode,qlonglong Position,qlonglong StartPosToAdd,
+                                      cSoundBlockList *SoundTrackMontage,double BlockPctDone,double ImagePctDone,cCompositionObject *PreviousCompositionObject,bool UseBrushCache,qlonglong ShotDuration,bool EnableAnimation,
+                                      bool Transfo=false,double NewX=0,double NewY=0,double NewW=0,double NewH=0,
+                                      bool DisplayTextMargin=false);
 
     void        SaveToXML(QDomElement &domDocument,QString ElementName,QString PathForRelativPath,bool ForceAbsolutPath,bool CheckTypeComposition=true);
     bool        LoadFromXML(QDomElement domDocument,QString ElementName,QString PathForRelativPath,cCompositionList *ObjectComposition,QStringList *AliasList,bool CheckTypeComposition=true);
 
+    QRectF      GetTextMargin(QRectF Workspace,double  ADJUST_RATIO);
+    void        ApplyTextMargin(int TMType);
+
     // Style managment functions
+    int         GetAutoCompoSize(int ffDProjectGeometry);
+    void        ApplyAutoCompoSize(int AutoCompoStyle,int ffDProjectGeometry);
+
     QString     GetCoordinateStyle();
     void        ApplyCoordinateStyle(QString StyleDef);
 
-    QString     GetFramingStyle();
-
     QString     GetTextStyle();
     void        ApplyTextStyle(QString StyleDef);
 
@@ -193,7 +181,7 @@ public:
     void        ApplyBlockShapeStyle(QString StyleDef);
 
 private:
-    QImage      AddShadow(QImage SourceImage,double &DstX,double &DstY,double &DstW,double &DstH,double Distance);
+    QRectF      GetPrivateTextMargin();
 };
 
 //*********************************************************************************************************************************************
@@ -238,7 +226,6 @@ public:
     int                     TypeObject;                 // Type of object
     QString                 SlideName;                  // Display name of the slide
     QList<cDiaporamaShot *> List;                       // list of scene definition
-    cFilterTransformObject  FilterTransform;            // Filters tranformation value for source image
 
     // Background definition
     bool                    BackgroundType;             // Background type : false=same as precedent - true=new background definition
@@ -259,6 +246,7 @@ public:
     int                     TransitionFamilly;          // Transition familly
     int                     TransitionSubType;          // Transition type in the familly
     qlonglong               TransitionDuration;         // Transition duration (in msec)
+    int                     TransitionSpeedWave;        // Transition SpeedWave
 
     QImage                  *Thumbnail;                 // Thumbnail cached image
     QList<cMusicObject>     MusicList;                  // List of music definition
@@ -273,6 +261,7 @@ public:
     void                    SaveToXML(QDomElement &domDocument,QString ElementName,QString PathForRelativPath,bool ForceAbsolutPath);
     bool                    LoadFromXML(QDomElement domDocument,QString ElementName,QString PathForRelativPath,QStringList *AliasList);
     qlonglong               GetTransitDuration();
+    int                     GetSpeedWave();
 };
 
 //*********************************************************************************************************************************************
@@ -313,7 +302,6 @@ public:
     //=====> Transitionnal object
     bool                IsTransition;                           // True if transition in progress
     double              TransitionPCTDone;                      // PCT achevement for transition
-    double              TransitionPCTEnd;                       // PCT achevement @ end of this frame for fade in/out
     int                 TransitionFamilly;                      // Transition familly
     int                 TransitionSubType;                      // Transition type in the familly
     qlonglong           TransitionDuration;                     // Transition duration (in msec)
@@ -365,6 +353,11 @@ public:
     int                     InternalWidth;          // Real width for image rendering
     int                     InternalHeight;         // Real height for image rendering
 
+    // Speed wave
+    int                     TransitionSpeedWave;    // Speed wave for transition
+    int                     BlockAnimSpeedWave;     // Speed wave for block animation
+    int                     ImageAnimSpeedWave;     // Speed wave for image framing and correction animation
+
     // slides objects
     QList<cDiaporamaObject *> List;                   // list of all media object
 
@@ -381,23 +374,15 @@ public:
     cMusicObject            *GetMusicObject(int ObjectIndex,qlonglong &StartPosition,int *CountObject=NULL,int *IndexObject=NULL);
     void                    DefineSizeAndGeometry(int Geometry);                        // Init size and geometry
     bool                    SaveFile(QWidget *ParentWindow);
-    bool                    LoadFile(QWidget *ParentWindow,QString &ProjectFileName);
-    bool                    AppendFile(QWidget *ParentWindow,QString ProjectFileName,int CurIndex);
     void                    UpdateChapterInformation();
 
     // Thread functions
     void                    PrepareMusicBloc(bool PreviewMode,int Column,qlonglong Position,cSoundBlockList *MusicTrack);
     void                    LoadSources(cDiaporamaObjectInfo *Info,double ADJUST_RATIO,int W,int H,bool PreviewMode,bool AddStartPos);
-    void                    DoAssembly(cDiaporamaObjectInfo *Info,int W,int H);
+    void                    DoAssembly(double PCT,cDiaporamaObjectInfo *Info,int W,int H);
 
-    // Transition
-    void                    DoBasic(cDiaporamaObjectInfo *Info,QPainter *P,int W,int H);
-    void                    DoZoom(cDiaporamaObjectInfo *Info,QPainter *P,int W,int H);
-    void                    DoSlide(cDiaporamaObjectInfo *Info,QPainter *P,int W,int H);
-    void                    DoPush(cDiaporamaObjectInfo *Info,QPainter *P,int W,int H);
-    void                    DoDeform(cDiaporamaObjectInfo *Info,QPainter *P,int W,int H);
-    void                    DoLuma(cLumaList *List,cDiaporamaObjectInfo *Info,QPainter *P,int W,int H);
-    QImage                  RotateImage(double TheRotateXAxis,double TheRotateYAxis,double TheRotateZAxis,QImage *OldImg);
+    // Memory
+    void                    CloseUnusedLibAv(int CurrentCell);
 
     // Threaded functions
     void LoadSourceVideoImage(cDiaporamaObjectInfo *Info,bool PreviewMode,int W,int H,bool AddStartPos);
