@@ -61,7 +61,7 @@ void QMovieLabel::SetImage(QImage *Image) {
     repaint();
 }
 
-void QMovieLabel::paintEvent(QPaintEvent */*event*/) {
+void QMovieLabel::paintEvent(QPaintEvent * /*event*/) {
     if (CurrentImage.isNull()) return;
     QPainter Painter(this);
     //Painter.save();
@@ -150,10 +150,8 @@ wgt_QVideoPlayer::wgt_QVideoPlayer(QWidget *parent) : QWidget(parent),ui(new Ui:
     tDuration               = QTime(0,0,0,0);
     ActualDisplay           = NULL;
     ResetPositionWanted     = false;
+    Deinterlace             = false;
 
-    ui->Position->setFixedWidth(DisplayMSec?80:60); ui->Position->setText(QTime(0,0,0,0).toString(DisplayMSec?"hh:mm:ss.zzz":"hh:mm:ss"));
-    ui->Duration->setFixedWidth(DisplayMSec?80:60); ui->Duration->setText(QTime(0,0,0,0).toString(DisplayMSec?"hh:mm:ss.zzz":"hh:mm:ss"));
-    ui->BufferState->setFixedWidth(DisplayMSec?80:60);
     this->FileInfo      = FileInfo;
     ui->CustomRuller->ActiveSlider(0);
     ui->CustomRuller->setSingleStep(25);
@@ -230,6 +228,12 @@ void wgt_QVideoPlayer::s_RightClickEvent(QMouseEvent *event) {
 
 //============================================================================================
 
+int wgt_QVideoPlayer::GetButtonBarHeight() {
+    return ui->VideoPlayerPlayPauseBT->height();
+}
+
+//============================================================================================
+
 void wgt_QVideoPlayer::resizeEvent(QResizeEvent *) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:wgt_QVideoPlayer::resizeEvent");
     Resize();
@@ -474,11 +478,12 @@ void wgt_QVideoPlayer::s_SliderMoved(int Value) {
     //***********************************************************************
     } else {
 
+        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         ActualDisplay=NULL;
 
         if (FileInfo) {
 
-            QImage *VideoImage=FileInfo->ImageAt(true,ActualPosition,0,NULL,1,false,NULL,false);
+            QImage *VideoImage=FileInfo->ImageAt(true,ActualPosition,0,NULL,Deinterlace,1,false,false);
             if (VideoImage) {
                 // Display frame
                 ui->MovieFrame->SetImage(VideoImage->scaledToHeight(ui->MovieFrame->height()));
@@ -486,6 +491,7 @@ void wgt_QVideoPlayer::s_SliderMoved(int Value) {
             }
 
         } else if (Diaporama) {
+
             // Create a frame from actual position
             cDiaporamaObjectInfo *Frame=new cDiaporamaObjectInfo(NULL,Value,Diaporama,double(1000)/WantedFPS);
             PrepareImage(Frame,false,true);         // This will add frame to the ImageList
@@ -516,6 +522,7 @@ void wgt_QVideoPlayer::s_SliderMoved(int Value) {
             // Free frame
             delete Frame;
         }
+        QApplication::restoreOverrideCursor();
     }
     GlobalMainWindow->InPlayerUpdate=false;
 }
@@ -623,7 +630,7 @@ void wgt_QVideoPlayer::PrepareImage(cDiaporamaObjectInfo *Frame,bool SoundWanted
     Diaporama->LoadSources(Frame,double(ui->MovieFrame->height())/double(1080),ui->MovieFrame->width(),ui->MovieFrame->height(),true,AddStartPos);
 
     // Do Assembly
-    Diaporama->DoAssembly(Frame,ui->MovieFrame->width(),ui->MovieFrame->height());
+    Diaporama->DoAssembly(ComputePCT(Frame->CurrentObject?Frame->CurrentObject->GetSpeedWave():0,Frame->TransitionPCTDone),Frame,ui->MovieFrame->width(),ui->MovieFrame->height());
 
     if ((SoundWanted)&&(Frame->CurrentObject)) {
         // Calc number of packet to mix
@@ -643,7 +650,7 @@ void wgt_QVideoPlayer::PrepareImage(cDiaporamaObjectInfo *Frame,bool SoundWanted
 
 void wgt_QVideoPlayer::PrepareVideoFrame(cDiaporamaObjectInfo *NewFrame,int Position) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:wgt_QVideoPlayer::PrepareVideoFrame");
-    QImage *Temp=FileInfo->ImageAt(true,Position,0,&MixedMusic,1,false,NULL,true);
+    QImage *Temp=FileInfo->ImageAt(true,Position,0,&MixedMusic,Deinterlace,1,false,true);
     if (Temp) {
         QImage *Temp2=new QImage(Temp->scaledToHeight(ui->MovieFrame->height()));
         NewFrame->RenderedImage=Temp2;
@@ -673,8 +680,10 @@ void wgt_QVideoPlayer::SetStartEndPos(int StartPos,int Duration,int PreviousStar
 
 void wgt_QVideoPlayer::SeekPlayer(int Value) {
     ToLog(LOGMSG_DEBUGTRACE,"IN:wgt_QVideoPlayer::SeekPlayer");
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     ActualPosition=-1;
     s_SliderMoved(Value);
+    QApplication::restoreOverrideCursor();
 }
 
 //============================================================================================
